# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import Nodes3DAPI.DynamicParameterUtil as DynamicParameterUtil
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibServices as FnGeolibServices
import Nodes3DAPI.IncomingSceneOpDelegates as IncomingSceneOpDelegates
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI_cmodule as Nodes3DAPI_cmodule
import PyFnAttribute
import PyXmlIO as PyXmlIO
import Utils as Utils
from Nodes3DAPI.Node3D import Node3D as Node3D
from Nodes3DAPI_cmodule import GetLeafAttrPairs as GetLeafAttrPairs
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

_ExtraHints: dict
_Parameter_XML: str

class Material(Node3D):
    _Material__incomingCookKey: ClassVar[str] = ...
    _Material__topLevelStaticHints: ClassVar[dict] = ...
    def __init__(self) -> None: ...
    def _Material__addDeepParam(self, parent, path, value: Incomplete | None = ...): ...
    def _Material__addShaderPair(self, parent, prefix, isCoshader: bool = ...): ...
    def _Material__checkDynamicParametersInternal(self, universalAttr, updateLastValue: bool = ...): ...
    def _Material__deleteDeepParam(self, path, deleteEmptyParentGroups: bool = ...): ...
    def _Material__findUniqueCoshaderName(self, renderer): ...
    def _Material__getCoshaderNames(self, renderer): ...
    def _Material__getMaterialAttrList(self, graphState: NodegraphAPI.GraphState): ...
    def _Material__getShaderTypeParameters(self): ...
    def _Material__isNetworkMaterial(self): ...
    def _Material__lastValueDiffers(self, param, currentValue, sourceTime, updateLastValue: bool = ...): ...
    def _Material__updateShaderTypeParamsWithAttr(self, paramsParam, paramsAttr, dynamicArrayAttrPaths, attrPrefix): ...
    def _cookAndWaitToUpdateParameters(self, updateLastValue: bool = ...): ...
    def _getIncomingSceneOpAndLocation(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, transaction): ...
    def _getOpChain(self, interface): ...
    def _getStaticAttrHintsForIncomingSceneQuery(self, attrPath): ...
    def _getUpdateParametersSupportedKeywords(self): ...
    def _updateParameters(self, groupAttr, force: bool = ..., defaultAttr: Incomplete | None = ..., updateLastValue: bool = ...): ...
    def addAttributeEntry(self, attr: PyFnAttribute.Attribute, path: str, hints: dict): ...
    def addCoshader(self, renderer, coshaderName): ...
    def addParameterHints(self, attrName, inputDict): ...
    def addShaderType(self, shaderType): ...
    def canOverride(self, attrName): ...
    def checkDynamicParameters(self, *args, **kwds): ...
    def clearParamHistory(self): ...
    def deleteAttributeEntry(self, index: int): ...
    def findOverrideParameter(self, path, attrName, time, **kwargs): ...
    def getAttributeEntries(self) -> NodegraphAPI.Parameter: ...
    def getInfoString(self): ...
    def getScenegraphLocation(self, sourceTime: int = ...): ...
    def initializeFromMaterialAttr(self, materialAttr): ...
    def isResetPossible(self): ...
    def removeAllShaders(self): ...
    def removeCoshader(self, coshaderName, renderer): ...
    def removeShaderAtPath(self, shaderParameterPath: str): ...
    def removeShaderType(self, shaderType, isCoshader: bool = ...): ...
    def renameCoshader(self, path, newName): ...
    def reorderAttributeEntries(self, oldPos: int, oldPosCount: int, newPos: int, newPosCount: int): ...
    def reorderAttributeEntry(self, oldPos: int, newPos: int): ...
    def setOverride(self, path, attrName, time, attrData, attrType: Incomplete | None = ..., attrTupleSize: Incomplete | None = ..., makeEmptyGroup: bool = ..., groupInherit: bool = ..., index: Incomplete | None = ...): ...
    def setShader(self, shaderType, shaderName): ...
    def setShaderParam(self, shaderType, paramName, newValue): ...

class ShaderPathComponents:
    class Role:
        PARAMETER: ClassVar[int] = ...
        PARAMETER_GROUP: ClassVar[int] = ...
        SHADER_NAME: ClassVar[int] = ...
    PATH_REGEX: ClassVar[str] = ...
    def __init__(self, canonicalPath, role, shaderType, parameterName, isCoshader) -> None: ...
    def _ShaderPathComponents__getPathForRole(self, role): ...
    @classmethod
    def _ShaderPathComponents__getPeerPathForPath(cls, path, pathRole, isCoshader): ...
    @classmethod
    def create(cls, path: str) -> ShaderPathComponents | None: ...
    def getCanonicalPath(self): ...
    def getParameterGroupPath(self): ...
    def getParameterName(self) -> str | None: ...
    def getRole(self): ...
    def getShaderNamePath(self): ...
    def getShaderType(self): ...
    def isCoshader(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import UI4.FormMaster.KatanaFactory as KatanaFactory
import UI4.Widgets.MessageBox as MessageBox
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyXmlIO as PyXmlIO
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import UI4.Widgets.SortablePanel
import Utils as Utils
from QT4Widgets.FilterablePopupButton import FilterablePopupButton as FilterablePopupButton
from QT4Widgets.MenuButton import MenuButton as MenuButton
from UI4.Util.ScenegraphLocation import GetNodesCreatingSceneGraphLocations as GetNodesCreatingSceneGraphLocations
from UI4.Widgets.SortablePanel import SortablePanelBase as SortablePanelBase, SortablePanelFormWidget as SortablePanelFormWidget
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class ScenegraphLocationArrayEditor(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    addMenuAboutToShow: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, policy, factory) -> None: ...
    def _ScenegraphLocationArrayEditor__addPath(self): ...
    def _ScenegraphLocationArrayEditor__appendNodegraphSelection(self, mid: Incomplete | None = ..., replace: bool = ...): ...
    def _ScenegraphLocationArrayEditor__appendScenegraphSelection(self, mid: Incomplete | None = ..., replace: bool = ..., selection: Incomplete | None = ...): ...
    def _ScenegraphLocationArrayEditor__clearAll(self): ...
    def _ScenegraphLocationArrayEditor__expandInScengraph(self): ...
    def _ScenegraphLocationArrayEditor__fillCollectMenu(self, menu): ...
    def _ScenegraphLocationArrayEditor__findItemChosen(self, text, meta): ...
    def _ScenegraphLocationArrayEditor__findPopupAboutToShow(self): ...
    def _ScenegraphLocationArrayEditor__getScenegraphSelection(self): ...
    def _ScenegraphLocationArrayEditor__pageDownButton_CB(self): ...
    def _ScenegraphLocationArrayEditor__pageUpButton_CB(self): ...
    def _ScenegraphLocationArrayEditor__replaceNodegraphSelection(self): ...
    def _ScenegraphLocationArrayEditor__replaceScenegraphSelection(self): ...
    def _ScenegraphLocationArrayEditor__updatePageButtons(self): ...
    def _popupMenuCreated(self, menu): ...
    def addButtonCheckDragEvent(self, event): ...
    def addButtonDropEvent(self, event): ...
    def buildAddMenu(self, menu): ...
    def getAbsoluteIndexFromRelative(self, relativeIndex): ...
    def getNumPages(self): ...
    def getPageIndex(self): ...
    def panelDeleted(self, relativeIndex): ...
    def panelReordered(self, relativeOldPos, relativeNewPos): ...
    def setLocked(self, state, checkLockOps: bool = ...): ...
    def setPageIndex(self, index): ...
    def updatePanels(self): ...

class ScenegraphLocationPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent, parentPolicy, index, extraHints: Incomplete | None = ...) -> None: ...
    def _ScenegraphLocationPanel__getChildPolicy(self): ...
    def getPathWidget(self): ...
    def getValuePolicy(self): ...
    def setLocked(self, state): ...
    def setPolicyIndex(self, index): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4 as UI4
import Utils as Utils
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from typing import Set, Tuple

class VPStateButton(ToolbarButton):
    def __init__(self, parent) -> None: ...
    def _VPStateButton__clicked(self): ...
    def _VPStateButton__setDirty(self, dirty): ...
    def _VPStateButton__updateCallback(self, args): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import Set, Tuple

class BaseLayoutResizer(PyQt5.QtWidgets.QFrame):
    def __init__(self, targetWidget: PyQt5.QtWidgets.QWidget, beforeTargetWidget: bool, orientation: PyQt5.QtCore.Qt.Orientation = ..., parent: Incomplete | None = ...) -> None: ...
    def enterEvent(self, event: PyQt5.QtCore.QEvent): ...
    def leaveEvent(self, event: PyQt5.QtCore.QEvent): ...
    def mouseMoveEvent(self, event: PyQt5.QtGui.QMouseEvent): ...
    def mousePressEvent(self, event: PyQt5.QtGui.QMouseEvent): ...
    def mouseReleaseEvent(self, event: PyQt5.QtGui.QMouseEvent): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import LayeredMenuAPI as LayeredMenuAPI
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from UI4.Tabs.BaseViewerTab import BaseViewerTab as BaseViewerTab
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4Panels.DragOverlay as DragOverlay
import QT4Panels.Edge as Edge
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class DragTabBar(DroppableTabBar):
    tabDoubleClick: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    tabRightMouse: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    tabStartDrag: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _DragTabBar__startDrag(self): ...
    def customEvent(self, event): ...
    def keyPressEvent(self, event): ...
    def keyReleaseEvent(self, event): ...
    def mouseDoubleClickEvent(self, event): ...
    def mouseMoveEvent(self, event): ...
    def mousePressEvent(self, event): ...
    def mouseReleaseEvent(self, event): ...

class DragTool:
    def __init__(self, source, index, pos, detach) -> None: ...
    def _IsSplittable(self, frame): ...
    def doDragEnd(self): ...
    def doDragMove(self, pos): ...
    def doDragStart(self): ...
    def doDrop(self): ...
    def doMove(self, pos): ...
    def isTargettingSource(self, widget, action, value): ...
    def positionRubberBand(self, widget, action, value, splittable): ...
    def setDetach(self, state): ...

class DroppableTabBar(PyQt5.QtWidgets.QTabBar):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _DroppableTabBar__clearDragTimer(self): ...
    def _DroppableTabBar__mouseDrag(self, event): ...
    def _DroppableTabBar__timerCallback(self): ...
    def dragEnterEvent(self, event): ...
    def dragLeaveEvent(self, event): ...
    def dragMoveEvent(self, event): ...
    def dropEvent(self, event): ...

class TabDragHandle(PyQt5.QtWidgets.QLabel):
    def __init__(self, parent, frame, index) -> None: ...
    def keyPressEvent(self, event): ...
    def keyReleaseEvent(self, event): ...
    def mouseMoveEvent(self, event): ...
    def mousePressEvent(self, event): ...
    def mouseReleaseEvent(self, event): ...
    def paintEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import PyFnGeolibServices.ExpressionMath as ExpressionMath
import PyFnGeolibServices as FnGeolibServices
import NodegraphAPI
import QT4GLLayerStack as QT4GLLayerStack
from QT4GLLayerStack.LayerStack import LayerStack
from typing import Set, Tuple

class BaseNodeGraphLayerStack(LayerStack):
    def frameNodes(self, nodes: list[NodegraphAPI.Node], zoom: bool = ...): ...
    def frameNodesOnBounds(self, zoom: bool, bounds: list[float], scales: list[float]): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
from . import RendererOutputUtil as RendererOutputUtil
from typing import Set, Tuple

class BinaryAttrWriter:
    def __init__(self, arg0: str) -> None: ...
    def tell(self) -> int: ...
    def writeAttr(self, arg0: PyFnAttribute.Attribute) -> None: ...

class GeometryProducer:
    def __init__(self, producerType: str, **kwargs) -> None: ...
    def getAttribute(self, name: str) -> PyFnAttribute.Attribute: ...
    def getAttributeNames(self) -> list: ...
    def getCacheID(self) -> str: ...
    def getChildByName(self, name: str) -> GeometryProducer: ...
    def getClient(self, *args, **kwargs): ...
    def getDelimitedGlobalAttribute(self, name: str) -> PyFnAttribute.Attribute: ...
    def getDelimitedLocalAttribute(self, name: str) -> PyFnAttribute.Attribute: ...
    def getFirstChild(self) -> GeometryProducer: ...
    def getFlattenedGlobalXform(self) -> tuple[float, float, float, float, float, float, float, float, float, float, float, float, float, float, float, float]: ...
    def getFnAttribute(self, name: str) -> PyFnAttribute.Attribute: ...
    def getFullName(self) -> str: ...
    def getGlobalAttribute(self, name: str) -> PyFnAttribute.Attribute: ...
    def getName(self) -> str: ...
    def getNextSibling(self) -> GeometryProducer: ...
    def getParent(self) -> GeometryProducer: ...
    def getPotentialChildren(self) -> PyFnAttribute.StringAttribute: ...
    def getProducerByPath(self, path: str) -> GeometryProducer: ...
    def getRootProducer(self) -> GeometryProducer: ...
    def getType(self) -> str: ...
    def iterChildren(self) -> GeometryProducer_childIter: ...
    def __hash__(self) -> int: ...

class GeometryProducer_childIter:
    def __init__(self, *args, **kwargs) -> None: ...
    def __iter__(self) -> GeometryProducer_childIter: ...
    def __next__(self): ...

def ClearLookFileCache() -> None: ...
def GetGeometryProducerList() -> list[str]: ...
def GetLookFilePassMaterials(asset: str, passName: str = ...) -> dict: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import UI4.Util.NotificationManager as NotificationManager
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4Widgets as QT4Widgets
import QT4Widgets.SortableTreeWidget
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
import QT4Widgets.WidgetUtils as WidgetUtils
from QT4Widgets.SortableTreeWidget import SortableTreeWidget
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from typing import ClassVar, Set, Tuple

class NotificationPopupWindow(PyQt5.QtWidgets.QFrame):
    hideSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    showSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self) -> None: ...
    def _NotificationPopupWindow__actionMenuAboutToShow(self): ...
    def _NotificationPopupWindow__contextMenuClick(self, pos): ...
    def _NotificationPopupWindow__fillActionMenu(self, menu): ...
    def hideEvent(self, e): ...
    def notificationAdded(self, record): ...
    def notificationDeleted(self, record): ...
    def setGeometry(self, x, y, w, h): ...
    def showEvent(self, e): ...
    def updateRecords(self, records): ...

class NotificationToolbarButton(ToolbarButton):
    def __init__(self, parent) -> None: ...
    def _NotificationToolbarButton__blinkWithPriorityState(self): ...
    def _NotificationToolbarButton__deleteRecordCallback(self, eventType, eventId, record): ...
    def _NotificationToolbarButton__mousePressCallback(self, event): ...
    def _NotificationToolbarButton__newRecordCallback(self, eventType, eventId, record): ...
    def _NotificationToolbarButton__popupHidden(self): ...
    def _NotificationToolbarButton__popupShow(self): ...
    def _NotificationToolbarButton__recordPriorityChangedCallback(self, eventType, eventId, record): ...
    def _NotificationToolbarButton__recordTitleChangedCallback(self, eventType, eventId, record): ...
    def _NotificationToolbarButton__setBlinkState(self, state): ...
    def _NotificationToolbarButton__timerCallback(self): ...
    def _NotificationToolbarButton__updatePriorityState(self): ...

class NotificationTreeWidget(SortableTreeWidget):
    ACTIONS_COLUMN: ClassVar[int] = ...
    DATE_COLUMN: ClassVar[int] = ...
    NAME_COLUMN: ClassVar[int] = ...
    PRIORITY_COLUMN: ClassVar[int] = ...
    contextMenuClick: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def _NotificationTreeWidget__keyPressCallback(self, event): ...
    def _NotificationTreeWidget__mousePressCallback(self, event): ...
    def adjustWidth(self, width): ...
    def deleteNotifications(self): ...
    def ignoreNotifications(self): ...
    def notificationAdded(self, record): ...
    def notificationDeleted(self, record): ...
    def notificationPriorityChanged(self, record): ...
    def notificationTitleChanged(self, record): ...
    def unignoreNotifications(self): ...
    def updateRecords(self, records): ...

class NotificationTreeWidgetItem(QT4Widgets.SortableTreeWidget.SortableTreeWidgetItem):
    def __init__(self, parent, record, icon) -> None: ...
    def updatePriority(self): ...
    def __lt__(self, other) -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def GetRegisteredActionClasses() -> list: ...
def RegisterActionClass(actionClass: type): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyUtilModule.EnvUtils as EnvUtils
import UI4.KatanaPrefs.PrefNames as PrefNames
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from typing import Set, Tuple

def openDocument(filename: str) -> bool: ...
def openFile(filename: str, command: str, verb: str = ...) -> bool: ...
def openFileForEdit(filename: str) -> bool: ...
def openImage(filename: str) -> bool: ...
def openUrl(url: str) -> bool: ...
def splitCommandLineString(command: str) -> list[str]: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import KatanaResources as KatanaResources
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import Utils as Utils
from typing import Set, Tuple

def GetSuperToolPluginEditor(name): ...
def GetSuperToolPluginNode(name): ...
def LoadSuperToolPlugins(loadEditors: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import Utils as Utils, Widgets as Widgets
from UI4.Widgets.MonitorLayer.MonitorLayer import MonitorLayer as MonitorLayer
from UI4.Widgets.MonitorLayer.Widgets import ToggleButton as ToggleButton, ToolBar as ToolBar
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Callbacks as Callbacks
import QT4FormWidgets.MenuUtils as MenuUtils
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import UI4.FormMaster.BaseParameterPolicy
import UI4.Widgets.SceneGraphView.Bridge
import PyUtilModule.UndoEntries as UndoEntries
import Utils as Utils
import typing
from QT4FormWidgets.ExpressionEditDialog import ExpressionEditDialog as ExpressionEditDialog
from UI4.Widgets.SceneGraphView.ColumnDataType import RegisterDataType as RegisterDataType
from UI4.Widgets.SceneGraphView.ItemDelegates.BaseItemDelegate import BaseItemDelegate as BaseItemDelegate
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class ParameterItemDelegate(BaseItemDelegate):
    _OnParameterSetCallbackID: ClassVar[None] = ...
    def __init__(self, bridge: Bridge[UI4.Widgets.SceneGraphView.Bridge.Bridge], treeWidget: PyQt5.QtWidgets.QTreeWidget, parent: Incomplete | None = ...) -> None: ...
    def _ParameterItemDelegate__on_cacheManager_flush(self): ...
    def _ParameterItemDelegate__on_closeEditor(self, editor: PyQt5.QtWidgets.QWidget, endEditHint: PyQt5.QtWidgets.QAbstractItemDelegate.EndEditHint): ...
    def _ParameterItemDelegate__on_sceneGraph_locationDeleted(self, eventType: str | None, eventID: object, locationPath: str): ...
    def _ParameterItemDelegate__on_sceneGraph_locationRenamed(self, eventType: str | None, eventID: object, oldLocationPath: str, newLocationPath: str, selectLocation: bool = ..., replaceSelection: bool = ...): ...
    def _ParameterItemDelegate__parameterPolicyEventHandler(self, valuePolicyEvent: QT4FormWidgets.ValuePolicy.ValuePolicyEvent): ...
    def canChangeSelection(self, index: PyQt5.QtCore.QModelIndex, event: PyQt5.QtCore.QEvent) -> bool: ...
    def clone(self, parent: Incomplete | None = ...) -> ParameterItemDelegate: ...
    def createContextMenu(self, index: PyQt5.QtCore.QModelIndex, selectedItems: list[PyQt5.QtWidgets.QTreeWidgetItem]) -> PyQt5.QtWidgets.QMenu | None: ...
    def createEditor(self, parent: PyQt5.QtWidgets.QWidget, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex) -> PyQt5.QtWidgets.QWidget | None: ...
    def doesParameterValueMatchModelValue(self, parameterPolicy: BaseParameterPolicy[UI4.FormMaster.BaseParameterPolicy.BaseParameterPolicy], index: PyQt5.QtCore.QModelIndex) -> bool: ...
    def editorClosed(self, editor: PyQt5.QtWidgets.QWidget, endEditHint: PyQt5.QtWidgets.QAbstractItemDelegate.EndEditHint): ...
    def executeOnParameterSetCallback(self, node: typing.Optional[NodegraphAPI.Node] = ..., parameterPolicy: Incomplete | None = ...): ...
    def getEditorClass(self) -> PyQt5.QtWidgets.QWidget | None: ...
    def getModelIndexesForEditing(self, editedCellIndex: PyQt5.QtCore.QModelIndex) -> list[PyQt5.QtCore.QModelIndex]: ...
    def getNodeAndParameterPolicy(self, index: PyQt5.QtCore.QModelIndex, requestIfNotCached: bool = ...) -> None: ...
    def getNodesAndParameterPoliciesForEditing(self, editedCellIndex: PyQt5.QtCore.QModelIndex, requestIfNotCached: bool = ...) -> list[None]: ...
    def getParameterPoliciesForEditing(self, editedCellIndex: PyQt5.QtCore.QModelIndex) -> list[BaseParameterPolicy[UI4.FormMaster.BaseParameterPolicy.BaseParameterPolicy]]: ...
    def getStateColor(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex) -> PyQt5.QtGui.QColor | None: ...
    def initStyleOption(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def setModelData(self, editor, model, index): ...
    def setNodeAndParameter(self, locationPath: str, node: NodegraphAPI.Node | None, parameter: NodegraphAPI.Parameter | None): ...
    def setShowFinalValue(self, state: bool): ...
    def showFinalValue(self) -> bool: ...
    def toolTipEvent(self, index: PyQt5.QtCore.QModelIndex): ...
    def updateEditorGeometry(self, editor: PyQt5.QtWidgets.QWidget, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import NodegraphAPI_cmodule
from NodegraphAPI_cmodule import PythonNode as PythonNode, node_addNodeFlavor as node_addNodeFlavor, node_registerPythonNodeType as node_registerPythonNodeType
from typing import ClassVar, Set, Tuple

class PythonRenderScript(NodegraphAPI_cmodule.PythonNode):
    PostRenderPublishContext: ClassVar[int] = ...
    PreRenderPublishContext: ClassVar[int] = ...
    RenderFrameContext: ClassVar[int] = ...
    def __init__(self) -> None: ...
    def addParameterHints(self, attrName, inputDict): ...
    def getActiveContexts(self): ...
    def postRenderPublish(self, versionup): ...
    def preRenderPublish(self, versionup): ...
    def renderFrame(self, graphState: NodegraphAPI.GraphState): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnGeolibProducers as FnGeolibProducers
import NodegraphAPI as NodegraphAPI
import NodegraphAPI_cmodule
import Utils as Utils
import re
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

REFMTL_ROOT: str
_DefaultShapeAttrs: tuple
_ExtraHints: dict
_Parameter_XML: str

class MaterialStackNode(NodegraphAPI_cmodule.PythonGroupNode):
    _MaterialStackNode__nodeReferenceRegex: ClassVar[re.Pattern] = ...
    def __init__(self) -> None: ...
    def _MaterialStackNode__conformAdoptedMaterials(self, parent, childList): ...
    def _MaterialStackNode__createMergeNode(self): ...
    def _MaterialStackNode__extractOrderedChildNodes(self, childList, resultList: Incomplete | None = ...): ...
    def _MaterialStackNode__findMaterialNodesInList(self, nodeList, resultList: Incomplete | None = ..., exceptionType: type[RuntimeError] = ...): ...
    def _MaterialStackNode__findReferencedMaterialNode(self, path): ...
    def _MaterialStackNode__getAppendedMergeInputPort(self, mergeNode: Incomplete | None = ...): ...
    def _MaterialStackNode__getMaterialParent(self, node: NodegraphAPI.Node): ...
    def _MaterialStackNode__getMergeInputIndexForNode(self, node: NodegraphAPI.Node, mergeNode: Incomplete | None = ...): ...
    def _MaterialStackNode__getMergeNode(self, create: bool = ...): ...
    def _MaterialStackNode__getReferenceGroupNode(self, create: bool = ...): ...
    def _MaterialStackNode__getReferenceGroupPruneNode(self): ...
    def _MaterialStackNode__getReferenceGroupTerminalPort(self): ...
    def _MaterialStackNode__layoutMaterialList(self, childList, state, depth: int = ...): ...
    def _MaterialStackNode__setReferencedMaterialInclusionSet(self, paths): ...
    def _MaterialStackNode__walkMaterialTree(self, node: NodegraphAPI.Node, materials): ...
    def addChildMaterial(self, parentNode): ...
    def addGeometryMaterial(self): ...
    def addLightMaterial(self): ...
    def addLookFileInReference(self, spref): ...
    def addLookFileMaterial(self): ...
    def addMaterial(self): ...
    def addParameterHints(self, attrName, inputDict): ...
    def addReferencedMaterial(self, path): ...
    def adoptMaterialNodes(self, nodeList, index: int = ..., exceptionType: type[RuntimeError] = ...): ...
    def deleteLookFileInReference(self, index): ...
    def deleteMaterialNode(self, node: NodegraphAPI.Node): ...
    def duplicateMaterial(self, node: NodegraphAPI.Node): ...
    def getAllChildMaterials(self, node: NodegraphAPI.Node): ...
    def getAllMaterialNodes(self): ...
    def getDefaultNodeShapeAttrs(self): ...
    def getLookFileInReferenceNodes(self): ...
    def getMaterialHierarchy(self, startAtNodeName: Incomplete | None = ...): ...
    def getReferenceGroupNode(self, create: bool = ...): ...
    def getReferenceGroupTerminalPort(self): ...
    def getReferenceMaterialDict(self): ...
    def getReferencedMaterialInclusionSet(self): ...
    def getReferencedMaterialNodeForPath(self, path): ...
    def layoutInternalGraph(self): ...
    def reorderLookFileInReference(self, fromIndex, toIndex): ...
    def reorderNode(self, node: NodegraphAPI.Node, parent, index): ...

def MiniPaste(element, parent): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CacheManager as CacheManager
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import NodegraphAPI
import PyFnAttribute
import PyFnGeolib
import Utils as Utils
import typing
from Nodes3DAPI.TerminalOpDelegates.TerminalOpDelegate import TerminalOpDelegate as TerminalOpDelegate
from PyUtilModule.WorkingSet import WorkingSet
from PyUtilModule.WorkingSetManager import WorkingSetManager as WorkingSetManager
from typing import ClassVar, Set, Tuple

class WorkingSetTerminalOpDelegate(TerminalOpDelegate):
    OP_TYPE: ClassVar[str] = ...
    def __init__(self) -> None: ...
    def _WorkingSetTerminalOpDelegate__addWorkingSet(self, workingSetName): ...
    def _WorkingSetTerminalOpDelegate__flushCaches(self): ...
    def _WorkingSetTerminalOpDelegate__generateOpArgs(self): ...
    def _WorkingSetTerminalOpDelegate__removeWorkingSet(self, workingSetName): ...
    def _WorkingSetTerminalOpDelegate__workingSetClearCallback(self, workingSet): ...
    def _WorkingSetTerminalOpDelegate__workingSetDeletedCallback(self, args): ...
    def _WorkingSetTerminalOpDelegate__workingSetLocationChangeCallback(self, locationStateChanges, workingSet, sender): ...
    def appendOp(self, op: PyFnGeolib.GeolibRuntimeOp, txn: PyFnGeolib.GeolibRuntimeTransaction, port: NodegraphAPI.Port | None, graphState: NodegraphAPI.GraphState) -> PyFnGeolib.GeolibRuntimeOp: ...
    def getWorkingSetNames(self) -> tuple[str, ...]: ...
    def setPolishOutput(self, workingSetName: str, polishOutput: bool): ...
    def setWorkingSetNames(self, workingSetNames: typing.Sequence[str]): ...
    def update(self) -> bool: ...

class _WorkingSetsInfoAttrsMap:
    def __init__(self) -> None: ...
    def addWorkingSet(self, name: str, workingSet: WorkingSet): ...
    def getName(self, workingSet: WorkingSet) -> str: ...
    def getWorkingSetAttr(self, name: str) -> PyFnAttribute.GroupAttribute: ...
    def getWorkingSetNames(self) -> list[str]: ...
    def removeWorkingSet(self, name: str): ...
    def updateWorkingSet(self, workingSet: WorkingSet): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import PyXmlIO as PyXmlIO
import Naming as UniqueName
import Utils as Utils
import re
from Nodes3DAPI.Node3D import Node3D as Node3D
from typing import ClassVar, Set, Tuple

class ForkNode3D(Node3D):
    _ForkNode3D__forkVarRegex: ClassVar[re.Pattern] = ...
    def __init__(self) -> None: ...
    def _ForkNode3D__renumberOutputPorts(self): ...
    def _ForkNode3D__renumberOutputVariables(self): ...
    def _getOp(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, visitedState, transaction): ...
    def addForkOutput(self): ...
    def addForkVariable(self, name, isString): ...
    def addParameterHints(self, attrName, inputDict): ...
    def deleteForkOutput(self, index): ...
    def deleteForkVariable(self, name): ...
    def renameForkVariable(self, oldName, newName): ...
    def reorderForkOutputVariables(self, oldPos, newPos): ...

def GetForkDictHash(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import types
from _typeshed import Incomplete
from typing import Any, Set, Tuple

NodegraphAPI: None
Nodes2DAPI: None
Nodes3DAPI: None
PyUtilModule: None

class SystemModuleFinder:
    def find_module(self, fullname: str, path: Incomplete | None = ...) -> Any | None: ...

class SystemModuleLoader:
    def load_module(self, fullname: str) -> types.ModuleType | None: ...

def ProcessEnvironmentVariables(): ...
def __main(): ...
def disableSpecificWarnings(): ...
def excepthook(exceptionType: type, exception: Exception, tb: types.TracebackType): ...
def initDefaultRenderer(): ...
def initNoQt(options): ...
def initQt(): ...
def initWithQt(options): ...
def makeTmpDirectory(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import PyFnGeolib as FnGeolib
import UI4.FormMaster.Editors.NodeGroup as NodeGroup
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.FWidget
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel as SortablePanel
import UI4 as UI4
import UI4.FormMaster.Editors.NodeGroup
import UI4.Widgets.SortablePanel
import Utils as Utils
from QT4FormWidgets.StringFormWidget import StringFormWidget
from typing import ClassVar, Set, Tuple

class IncludedOutputToggle(PyQt5.QtWidgets.QCheckBox):
    toggledWithName: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, name, parent) -> None: ...
    def _IncludedOutputToggle__toggled(self, on): ...

class IncludedOutputsFMenu(QT4FormWidgets.FWidget.FMenu):
    def mousePressEvent(self, event): ...

class RenderNodeEditor(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _RenderNodeEditor__actionButtonFillMenu(self, menu): ...
    def _RenderNodeEditor__allIncludedOutputsOff(self): ...
    def _RenderNodeEditor__allIncludedOutputsOn(self): ...
    def _RenderNodeEditor__allIncludedOutputsReset(self): ...
    def _RenderNodeEditor__includedOutputToggled(self, name, on): ...
    def _RenderNodeEditor__includedOutputsAboutToHide(self): ...
    def _RenderNodeEditor__includedOutputsFillMenu(self, menu): ...
    def _RenderNodeEditor__postCreateAssets(self, versionUp: bool = ...): ...
    def _RenderNodeEditor__postCreateAssetsVersionUp(self): ...
    def _RenderNodeEditor__preCreateAssets(self, versionUp: bool = ...): ...
    def _RenderNodeEditor__preCreateAssetsVersionUp(self): ...

class RenderOutputPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent, outputInfo, enabledValuePolicy, outputIndex, compact) -> None: ...
    def _RenderOutputPanel__actionMenuAboutToShow(self): ...
    def _RenderOutputPanel__copyExpression(self): ...
    def _RenderOutputPanel__enabledCheckBoxToggled(self, on): ...
    def _RenderOutputPanel__enabledValuePolicyChanged(self, event): ...
    def _RenderOutputPanel__getMyNode(self): ...
    def _RenderOutputPanel__postCreateAsset(self, versionUp: bool = ...): ...
    def _RenderOutputPanel__postCreateAssetVersionUp(self): ...
    def _RenderOutputPanel__preCreateAsset(self, versionUp: bool = ...): ...
    def _RenderOutputPanel__preCreateAssetVersionUp(self): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def refreshVersionInfo(self): ...
    def setDisplayStateFromOutputInfo(self, outputInfo): ...
    def setLocked(self, state): ...
    def updateLocationField(self): ...

class RenderOutputsEditor(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _RenderOutputsEditor__handlePassNamePolicyEvent(self, event): ...
    def _RenderOutputsEditor__idle(self, *args, **kwds): ...
    def _RenderOutputsEditor__refreshVersionInfo(self, event, eventId, *args, **kwargs): ...
    def _RenderOutputsEditor__setLabel(self, num): ...
    def _RenderOutputsEditor__syncWithIncomingScenegraph(self): ...
    def _RenderOutputsEditor__terminalOpCallback(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, op, transaction): ...
    def _freeze(self): ...
    def _participatesInLabelAlignment(self): ...
    def _thaw(self): ...
    def manualSyncIncoming(self): ...
    def refreshVersionInfo(self): ...
    def setErrorMessage(self, msg): ...
    def updateOutputs(self, outputInfoList): ...

class RenderPassnameEditor(StringFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _RenderPassnameEditor__updateWarning(self): ...
    def valueChangedEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
from _typeshed import Incomplete
from typing import Set, Tuple

class BaseNodeActionDelegate:
    def addToContextMenu(self, menu, node: NodegraphAPI.Node): ...
    def addToWrenchMenu(self, menu, node: NodegraphAPI.Node, hints: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import IconManager as IconManager
from ResourceFiles.IconManager import QT4IconManager as QT4IconManager
from ResourceFiles.ResourceManager import ResourceManager as ResourceManager
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import LiveRenderOpChain as LiveRenderOpChain, LiveRenderPortOpObserver as LiveRenderPortOpObserver, RerenderEvents as RerenderEvents
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import QT4FormWidgets as QT4FormWidgets
import Utils as Utils
from QT4FormWidgets.PopupFormWidget import PopupFormWidget
from typing import Set, Tuple

class InputPortNamePopupFormWidget(PopupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _InputPortNamePopupFormWidget__node_addOrRemoveInputPort_cb(self, eventType, eventID, nodeName, portName, port: NodegraphAPI.Port, **kwargs): ...
    def _InputPortNamePopupFormWidget__node_renameInputPort_cb(self, eventType, eventID, **kwargs): ...
    def _InputPortNamePopupFormWidget__registerEventHandlers(self): ...
    def _InputPortNamePopupFormWidget__unregisterEventHandlers(self): ...
    def _InputPortNamePopupFormWidget__update(self): ...
    def _freeze(self): ...
    def _thaw(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import PyUtilModule.FarmAPI as FarmAPI
import NodegraphAPI as NodegraphAPI
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from UI4.Widgets.ProductSaveWidgets import FileSaveWidget as FileSaveWidget
from UI4.Widgets.SortableListWidget import SortableListWidget as SortableListWidget, SortableListWidgetItem as SortableListWidgetItem
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class FarmDefaultDialog(PyQt5.QtWidgets.QDialog):
    _TimestampFormat: ClassVar[str] = ...
    _TimestampRegex: ClassVar[str] = ...
    _pathRe: ClassVar[None] = ...
    def __init__(self, generateCallbackHandle: Incomplete | None = ..., title: str = ..., fileExtension: str = ...) -> None: ...
    def _FarmDefaultDialog__aboutToShowFileSaveMenu(self): ...
    def _FarmDefaultDialog__calcOutlineFileNameBase(self, fileLocation): ...
    def _FarmDefaultDialog__createDir(self): ...
    def _FarmDefaultDialog__extractFarmFileLocation(self): ...
    def _FarmDefaultDialog__fileTextChangedCallback(self, text): ...
    def _FarmDefaultDialog__generateClicked(self): ...
    def _FarmDefaultDialog__getDefaultDirectory(self): ...
    def _FarmDefaultDialog__getDefaultFileLocation(self, defaultPath: Incomplete | None = ...): ...
    def _FarmDefaultDialog__loadSettings(self): ...
    def _FarmDefaultDialog__resetPath(self): ...
    def _FarmDefaultDialog__saveClicked(self): ...
    def _FarmDefaultDialog__saveSettingsToRootNode(self): ...
    def _FarmDefaultDialog__settingsGroupVisibilityChange(self, vpEvent): ...
    def _FarmDefaultDialog__updateInfoWidgets(self): ...
    def _FarmDefaultDialog__updateState(self): ...
    def _FarmDefaultDialog__validityChangeCallback(self, state): ...
    def _FarmDefaultDialog__versionUpAndSaveClicked(self): ...
    def getValuePolicy(self): ...

def GenerateFarmCreateSettingsOnRootNode(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.RenderManager as RenderManager
import PyResolutionTableFn as ResolutionTable
import UI4 as UI4
from QT4FormWidgets.ArrayFormWidget import ArrayFormWidget
from typing import Set, Tuple

class CropWindowEditor(ArrayFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _CropWindowEditor__actionButton_menu(self, menu): ...
    def _CropWindowEditor__copyFromMonitorROI(self): ...
    def _CropWindowEditor__copyToMonitorROI(self): ...
    def _CropWindowEditor__getDataWindow(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from PyQt5.QtWidgets import GlobalActions as GlobalActions
from typing import Set, Tuple

class RedoAction(PyQt5.QtWidgets.QAction):
    def __init__(self, parent, hotkey) -> None: ...
    def _RedoAction__on_triggered(self): ...

class UndoAction(PyQt5.QtWidgets.QAction):
    def __init__(self, parent, hotkey) -> None: ...
    def _UndoAction__on_triggered(self): ...

def GetHotkeys(context: PyQt5.QtCore.Qt.ShortcutContext = ...) -> list: ...
def InitializeHotkeys(): ...
def ProcessHotkeyEvent(event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import PyOpenColorIO as OCIO
import QT4Color as QT4Color
import QT4FormWidgets as QT4FormWidgets
import UI4 as UI4
import Utils as Utils
from QT4Color.ColorFormWidget import ColorFormWidget
from QT4FormWidgets.PopupFormWidget import PopupFormWidget
from typing import Set, Tuple

class ColorspacePopup(PopupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _ColorspacePopup__updateInfo(self): ...
    def _ColorspacePopup__valueChanged(self, event): ...
    def _freeze(self): ...
    def _thaw(self): ...

class KatanaColorFormWidget(ColorFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _KatanaColorFormWidget__probeResult_CB(self, probeInfo): ...
    def _buildAdditionalControlWidgets(self, layout): ...
    def colorChange(self, color): ...
    def execColorPicker(self): ...
    def setColor_RGBA(self, color, final: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import QT4Widgets.TextEditorUtils as TextEditorUtils
import UI4 as UI4
import Utils as Utils
import code
import re
import typing
from typing import ClassVar, Set, Tuple

class FullInteractivePython(PyQt5.QtWidgets.QFrame):
    def __init__(self, *args, **kwargs) -> None: ...
    def _FullInteractivePython__buildChildren(self): ...
    def _FullInteractivePython__buildCommands(self): ...
    def _FullInteractivePython__buildMenuBar(self): ...
    def _FullInteractivePython__on_preferencesAction_triggered(self): ...
    def _FullInteractivePython__sourceFileCallback(self): ...
    def getMenuBar(self) -> PyQt5.QtWidgets.QMenuBar: ...
    def scriptWidget(self) -> InteractivePython: ...

class InteractivePython(PyQt5.QtWidgets.QFrame):
    class CustomInterp(code.InteractiveInterpreter):
        def __init__(self, outputwidget) -> None: ...

    class _CommandEntryWidget(PyQt5.QtWidgets.QTextEdit):
        backtabPressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        editingFinished: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        enterPressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        returnPressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        tabPressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
        def __init__(self, *args) -> None: ...
        def _CommandEntryWidget__formatDocument(self, selectionOnly: bool): ...
        def _CommandEntryWidget__formatText(self, text: str, lineIndices) -> str | None: ...
        def _CommandEntryWidget__on_pref_changed(self, eventType: str | None, eventID: typing.Hashable, prefKey: str, prefValue: object): ...
        def _CommandEntryWidget__returnKeyPressEvent(self, event: PyQt5.QtGui.QKeyEvent): ...
        def _CommandEntryWidget__toggleComment(self): ...
        def _sanitiseMimeData(self, mimeData): ...
        def contextMenuEvent(self, event: PyQt5.QtGui.QContextMenuEvent): ...
        def dragEnterEvent(self, event): ...
        def dragMoveEvent(self, event): ...
        def dropEvent(self, event): ...
        def focusOutEvent(self, event: PyQt5.QtGui.QFocusEvent): ...
        def getFormatAllAction(self) -> PyQt5.QtWidgets.QAction: ...
        def getFormatSelectionAction(self) -> PyQt5.QtWidgets.QAction: ...
        def getToggleCommentAction(self) -> PyQt5.QtWidgets.QAction: ...
        def insertFromMimeData(self, mimeData): ...
        def keyPressEvent(self, keyEvent): ...
        def keyReleaseEvent(self, keyEvent): ...
        def paintEvent(self, event: PyQt5.QtGui.QPaintEvent): ...

    class _ResultWidget(PyQt5.QtWidgets.QTextEdit):
        def __init__(self, *args) -> None: ...
        def keyPressEvent(self, keyEvent): ...

    class _ScriptStderr:
        def __init__(self, resultWidget, realstderr) -> None: ...
        def flush(self): ...
        def write(self, msg): ...

    class _ScriptStdin:
        def __init__(self, scriptWidget) -> None: ...

    class _ScriptStdout:
        def __init__(self, resultWidget) -> None: ...
        def flush(self): ...
        def write(self, msg): ...
    _InteractivePython__customFormatFunction: ClassVar[None] = ...
    _InteractivePython__identifier: ClassVar[re.Pattern] = ...
    aboutToExecuteCode: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    assMidgetCmd: ClassVar[re.Pattern] = ...
    def __init__(self, *args) -> None: ...
    def _InteractivePython__buildCommandWidget(self): ...
    def _InteractivePython__buildResultWidget(self): ...
    def _InteractivePython__echoCommand(self, commandString): ...
    def _autoComplete(self): ...
    def _enterCommand(self): ...
    def _indentCommand(self): ...
    def _unindentCommand(self): ...
    def clear(self): ...
    def commandWidget(self): ...
    def copy(self): ...
    def cut(self): ...
    @classmethod
    def getCustomFormatFunction(cls) -> typing.Callable | None: ...
    def getEnvironment(self): ...
    def nextHist(self): ...
    def on_commandWidget_tabPressed(self): ...
    def paste(self): ...
    def prevHist(self): ...
    def printMessage(self, messageString): ...
    def resultWidget(self): ...
    def runCommand(self, commandString): ...
    @classmethod
    def setCustomFormatFunction(cls, customFormatFunction: typing.Callable | None): ...
    def setEnvironment(self, env): ...
    def setUseAutoCompletionPopup(self, useAutoCompletionPopup): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.Editors.SortableArray
import UI4.Widgets.SortablePanel
import Utils as Utils
from UI4.FormMaster.Editors.SortableArray import SortableArrayEditor as SortableArrayEditor
from UI4.Widgets.SortablePanel import SortablePanelBase as SortablePanelBase
from typing import Set, Tuple

class InterwovenArrayGroupEditor(UI4.FormMaster.Editors.SortableArray.SortableArrayEditor):
    def __init__(self, parent, policy, factory) -> None: ...
    def _InterwovenArrayGroupEditor__childValueChanged(self, event): ...
    def _InterwovenArrayGroupEditor__idle_callback(self, *args, **kwds): ...
    def _InterwovenArrayGroupEditor__update(self): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def newEntry(self): ...
    def panelDeleted(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def updatePanels(self): ...

class InterwovenArrayPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent, policies, factory) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibServices as FnGeolibServices
import Nodes3DAPI as Nodes3DAPI
import PyFnGeolib
from typing import Set, Tuple

class ImplicitOpsManager:
    def __init__(self) -> None: ...
    def _ImplicitOpsManager__createOpChainFromOpInfo(self, txn: PyFnGeolib.GeolibRuntimeTransaction, opsInfo: list[str, Attribute, bool]) -> list[PyFnGeolib.GeolibRuntimeOp]: ...
    def _ImplicitOpsManager__initAfterImplicitOps(self, txn: PyFnGeolib.GeolibRuntimeTransaction) -> list[PyFnGeolib.GeolibRuntimeOp]: ...
    def _ImplicitOpsManager__initBeforeImplicitOps(self, txn: PyFnGeolib.GeolibRuntimeTransaction) -> list[PyFnGeolib.GeolibRuntimeOp]: ...
    def _ImplicitOpsManager__initImplicitOps(self, txn: PyFnGeolib.GeolibRuntimeTransaction) -> list[PyFnGeolib.GeolibRuntimeOp]: ...
    def _ImplicitOpsManager__initOps(self): ...
    def applyAfterImplicitOps(self, txn, op): ...
    def applyBeforeImplicitOps(self, txn, op): ...
    def applyImplicitOps(self, txn, op): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import KatanaResources as KatanaResources
import Shelves
import Utils as Utils
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

SHELF_TYPE_BUILTIN: int
SHELF_TYPE_CUSTOM: int
SHELF_TYPE_UNKNOWN: int
SHELF_TYPE_USER: int

class Shelf:
    def __init__(self, name, path, shelfType, shelfTypeStr: Incomplete | None = ...) -> None: ...
    def _Shelf__triggerChange(self): ...
    def append(self, item): ...
    def createItem(self, name: str, description: str, keyboardShortcut: str = ..., icon: Incomplete | None = ...) -> Shelves.ShelfItem: ...
    def createNewItem(self, name, desc, dropTypes, icon): ...
    def find(self, name): ...
    def getEditable(self): ...
    def getItems(self): ...
    def getName(self): ...
    def getPath(self): ...
    def getType(self): ...
    def getTypeStr(self): ...
    def load(self): ...
    def remove(self, item): ...
    def replace(self, oldItem, newItem): ...

class ShelfItem:
    _defaultPixmap: ClassVar[None] = ...
    def __init__(self, name: str, icon: str, keyboardShortcut: str, description, sourceFile: str, scope: tuple = ...) -> None: ...
    def _ShelfItem__isScopeValid(self, nodeTypes: list) -> bool: ...
    def deleteSourceFile(self): ...
    def getCode(self): ...
    def getDescription(self): ...
    def getDropTypes(self): ...
    def getIconName(self): ...
    def getKeyboardShortcut(self) -> str: ...
    def getName(self): ...
    def getScope(self): ...
    def getSourceFile(self): ...
    def getSourceFilename(self): ...
    def run(self, additionalEnvironment: Incomplete | None = ..., checkScope: bool = ...): ...
    def setKeyboardShortcut(self, shortcut: str): ...
    def setScope(self, scope: list): ...
    def sourceFileExists(self): ...

def CreateShelfItem(shelfItemFilename): ...
def CreateUserShelf(shelfName, suffix: str = ...): ...
def GetBuiltinShelves(): ...
def GetShelves2(forceReload: bool = ...): ...
def GetShelvesWithSuffix(suffix, forceReload: bool = ...): ...
def GetUserShelves(suffix: str = ...): ...
def ParseFile(filename: str) -> dict: ...
def RegisterPrintHandler(callback): ...
def RegisterShelfTypeCallback(callback): ...
def ShelfPrint(message, important: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import PyXmlIO as PyXmlIO
import Utils as Utils
from Nodes3DAPI.Node3D import Node3D as Node3D
from Utils.Decorators import deprecated as deprecated
from typing import Set, Tuple

_ExtraHints: dict
_Parameter_XML: str

class Isolate(Node3D):
    def __init__(self) -> None: ...
    def _getOpChain(self, interface): ...
    def addIsolatePatternEntry(self, value): ...
    def addIsolateValueEntry(self, value): ...
    def addParameterHints(self, attrName, inputDict): ...
    def enableSecondaryOutput(self, isEnabled): ...
    def enableSecondayOutput(self, isEnabled): ...
    def isSecondaryOutputEnabled(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import MachineInfo.MachineInfo as MachineInfo
from _typeshed import Incomplete
from typing import Set, Tuple

def GetImageDiskMemoryMB(isBatch, customLogger: Incomplete | None = ...): ...
def GetImageMemoryMB(isBatch, customLogger: Incomplete | None = ...): ...
def GetRenderThreadCount(): ...
def GetRenderTileSize(customLogger: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import ClassVar, Set, Tuple

class MiniLabelButton(PyQt5.QtWidgets.QLabel):
    clicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, text, parent) -> None: ...
    def mousePressEvent(self, _ev): ...
    def paintEvent(self, ev): ...

class StripedFrame(PyQt5.QtWidgets.QFrame):
    def paintEvent(self, ev): ...

def SetCompactWidgetWidth(w, padding: int = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui as QtGui
from typing import Set, Tuple

def GetCapsuleArgsFromHints(hints): ...
def GetColorList(listHint): ...
def GetMapping(mappingHint, numberValues: bool = ..., order: list = ...): ...
def GetSliderArgsFromHints(hints): ...
def GetStringList(listHint): ...
def HintTrue(hintName: str, hints: dict, default: bool = ...) -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Callbacks as Callbacks
import PyFnAttribute as FnAttribute
import PyFnAttribute
import PyUtilModule.RenderingCommon as RenderingCommon
import Utils as Utils
from . import PluginActionRegistry as PluginActionRegistry
from _typeshed import Incomplete
from typing import Set, Tuple

kVirtualCameraSceneGraphLocation: str

def AppendTerminalOp(opKey: object, opType: str, opArgs: PyFnAttribute.GroupAttribute): ...
def ClearAllTerminalOps(): ...
def GetTerminalOps() -> list[None]: ...
def InsertTerminalOp(opKey: object, opType: str, opArgs: PyFnAttribute.GroupAttribute, insertIndex: int): ...
def RemoveTerminalOp(opKey: object, deferred: bool = ...): ...
def RestoreDefaultTerminalOps(): ...
def SendCommand(command: str): ...
def SendData(dataType: str | StringAttribute, locationPath: str | StringAttribute, attributes: PyFnAttribute.GroupAttribute): ...
def SetLiveAttribute(locationPath: str, attrPath: str, attrValue: PyFnAttribute.Attribute, attrEditor: Incomplete | None = ...): ...
def SetVirtualCameraAttributes(attributes: PyFnAttribute.GroupAttribute): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes3DAPI.DynamicParameterUtil as DynamicParameterUtil
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI_cmodule as Nodes3DAPI_cmodule
import Utils as Utils
from Nodes3DAPI.Node3D import Node3D as Node3D
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

_ParamHints: dict
_Parameter_XML: str

class TransformEditNode(Node3D):
    Action_addNewTransform: ClassVar[str] = ...
    Action_overrideInteractive: ClassVar[str] = ...
    Action_replaceAll: ClassVar[str] = ...
    def __init__(self) -> None: ...
    def _TransformEditNode__getOverrideParameterPath(self, attrPath: str, index: Incomplete | None = ...) -> str | None: ...
    def _getIncomingSceneOpAndLocation(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, transaction): ...
    def _getOpChain(self, interface): ...
    def _getStaticAttrHintsForIncomingSceneQuery(self, attrPath: str) -> dict: ...
    def _updateParameters(self, groupAttr, force: bool = ..., defaultAttr: Incomplete | None = ...): ...
    def addParameterHints(self, attrName, inputDict): ...
    def canOverride(self, attrName): ...
    def checkDynamicParameters(self): ...
    def findOverrideParameter(self, path, attrName, time, index: Incomplete | None = ..., editable: bool = ...): ...
    def getScenegraphLocation(self, frameTime: float = ...) -> str: ...
    def setInteractiveTransform(self, path, absScale, absRotate, absTranslate, time): ...
    def setInteractiveTransformFlag(self, path, time): ...
    def setOverride(self, locationPath, attrName, frameTime, attrData, index: Incomplete | None = ..., **kwargs): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def GetFreeSpaceB(dirName): ...
def GetMount(dirName): ...
def GetPrettySize(sizeInBytes): ...
def GetTotalSizeOfMountB(dirName): ...
def GetUsedSpaceB(dirName): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import KeyboardShortcutItem as KeyboardShortcutItem, KeyboardShortcutManager as KeyboardShortcutManager, KeyboardShortcutManagerMixin as KeyboardShortcutManagerMixin, KeyboardShortcutModel as KeyboardShortcutModel, ManagedAction as ManagedAction
from UI4.App.KeyboardShortcutManager.KeyboardShortcutManager import BindActions as BindActions, BuildShortcutModel as BuildShortcutModel, CreateAction as CreateAction, GenerateActionID as GenerateActionID, GetActionID as GetActionID, GetFullActionName as GetFullActionName, GetFullKeyEventName as GetFullKeyEventName, GetKeyEventID as GetKeyEventID, GetKeyEventNameForShortcut as GetKeyEventNameForShortcut, GetShortcutForAction as GetShortcutForAction, GetShortcutForKeyEvent as GetShortcutForKeyEvent, HandleKeyEvent as HandleKeyEvent, IsShortcutRegisteredForAction as IsShortcutRegisteredForAction, IsShortcutRegisteredForClass as IsShortcutRegisteredForClass, LoadShortcuts as LoadShortcuts, RegisterAction as RegisterAction, RegisterActions as RegisterActions, RegisterKeyEvent as RegisterKeyEvent, UnregisterAction as UnregisterAction, UnregisterKeyEvent as UnregisterKeyEvent, UpdateAction as UpdateAction
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PackageSuperToolAPI.NodeUtils as NU
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import PackageSuperToolAPI.Packages
import Packages as Packages
import PyFnAttribute
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import UI4.Widgets.SceneGraphView.SceneGraphLocationTranslation as SceneGraphLocationTranslation
import UI4.Util.ScenegraphIconManager as ScenegraphIconManager
import UI4 as UI4
import UI4.NodeMaster.NodeInteractionDelegateManager
import UI4.Widgets
import PackageSuperToolAPI.UIDelegate as UIDelegate
import Utils as Utils
import typing
from BaseNode import BaseNode
from PyUtilModule.VirtualKatana import Decorators as Decorators, FormMaster as FormMaster, NodeMaster as NodeMaster, QtCore as QtCore, QtWidgets as QtWidgets, ScenegraphManager as ScenegraphManager
from UI4.Widgets.SceneGraphView.ColumnDataType import ColumnDataType as ColumnDataType
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

LAYOUT_HORIZONTAL: int
LAYOUT_VERTICAL: int
SYNC_SELECTION_IN_OUT: float
SYNC_SELECTION_OFF: float
SYNC_SELECTION_OUT: float

class BaseEditor(PyQt5.QtWidgets.QWidget):
    class _PackageValidityStatus:
        NOT_IN_INPUT: ClassVar[int] = ...
        NO_SUCH_PACKAGE: ClassVar[int] = ...
        OK: ClassVar[int] = ...
        TYPE_MISMATCH: ClassVar[int] = ...
        @classmethod
        def textForStatusCode(cls, code): ...

    class _TabAreaState:
        EDIT: ClassVar[int] = ...
        ERROR: ClassVar[int] = ...
        INACTIVE: ClassVar[int] = ...
        def __init__(self, locationPath, statusCode) -> None: ...
        @classmethod
        def Edit(cls, locationPath): ...
        @classmethod
        def Error(cls, locationPath): ...
        @classmethod
        def Inactive(cls): ...
        def getLocationPath(self): ...
        def getStatusCode(self): ...
        def __eq__(self, rhs) -> bool: ...
        def __ne__(self, rhs) -> bool: ...

    class _TabAreaUpdate:
        USE_CURRENT_SELECTION: ClassVar[object] = ...
        def __init__(self, locationPath) -> None: ...
        @classmethod
        def Location(cls, locationPath): ...
        @classmethod
        def Selection(cls): ...
        def getLocationPath(self) -> USE_CURRENT_SELECTION | str | None: ...
    AddPackageRegistry: ClassVar[dict] = ...
    PackageMenuActionsRegistry: ClassVar[dict] = ...
    SEPARATOR: ClassVar[str] = ...
    TAB_AREA_UPDATE_INTERVAL: ClassVar[int] = ...
    _BaseEditor__HasRegisteredKeyboardShortcuts: ClassVar[bool] = ...
    def __init__(self, parent: PyQt5.QtWidgets.QWidget | None, node: NodegraphAPI.Node) -> None: ...
    def _BaseEditor__aboutToDragCallback(self, items, dragObject): ...
    def _BaseEditor__actionMenuAboutToShow(self): ...
    def _BaseEditor__addPackage(self): ...
    def _BaseEditor__adoptLocationsForEditing(self, locationPaths: list[str], locationAttributes: list[PyFnAttribute.GroupAttribute | PyFnAttribute.GroupAttribute]): ...
    def _BaseEditor__buildToolbar(self): ...
    def _BaseEditor__canAnySelectedPackageBeDeleted(self) -> bool: ...
    def _BaseEditor__canAnySelectedPackageBeDuplicated(self) -> bool: ...
    def _BaseEditor__configureSceneGraphView(self): ...
    def _BaseEditor__configureTabWidget(self): ...
    def _BaseEditor__contextMenuEventHandler(self, contextMenuEvent, menu): ...
    def _BaseEditor__createChildPackage(self, children: list[str], parentPackage: PackageSuperToolAPI.Packages.Package, packageClass: type): ...
    def _BaseEditor__deletePackage(self): ...
    def _BaseEditor__dispatchPackageMenuAction(self): ...
    def _BaseEditor__dragMoveEventCallback(self, dragMoveEvent, draggedItems, parentItem, childItemIndex): ...
    def _BaseEditor__dropEventCallback(self, dropEvent, droppedItems, parentItem, childItemIndex): ...
    def _BaseEditor__duplicatePackage(self): ...
    def _BaseEditor__freeze(self): ...
    def _BaseEditor__getAndValidatePackageForPath(self, locationPath: str) -> Tuple[Packages.Package, _PackageValidityStatus]: ...
    def _BaseEditor__getGlobalOrdering(self, items: list[QTreeWidgetItem]) -> list[QTreeWidgetItem]: ...
    def _BaseEditor__getIncomingChildCount(self, parent: QTreeWidgetItem | None) -> int: ...
    def _BaseEditor__getInternalViewPort(self): ...
    def _BaseEditor__hideTabsLabel(self): ...
    def _BaseEditor__iterTabs(self) -> typing.Iterator[str, PyQt5.QtWidgets.QWidget]: ...
    def _BaseEditor__locationAddedOrUpdatedCallback(self, locationPath, topLevelLocationPath): ...
    def _BaseEditor__mainNodeParameterFinalizedHandler(self, args): ...
    def _BaseEditor__nodeSetLockedChanged(self, *args): ...
    def _BaseEditor__on_cachedWidgetDestroyed(self, cache: dict, cacheKey: str): ...
    def _BaseEditor__on_scenegraphManager_pinChanged(self, eventType, eventID, locations, sender): ...
    def _BaseEditor__on_scenegraphManager_selectionChanged(self, *args): ...
    def _BaseEditor__on_tabAreaUpdateTimer_timeout(self): ...
    def _BaseEditor__overrideParameterRequestCallback(self, overrideParameters): ...
    def _BaseEditor__populateAddMenu(self, menu: PyQt5.QtWidgets.QMenu, package: PackageSuperToolAPI.Packages.Package): ...
    def _BaseEditor__populateStandardContextMenuItems(self, menu): ...
    def _BaseEditor__potentialPortViewChangeHandler(self, args): ...
    def _BaseEditor__registerDestructionCallback(self, widget: PyQt5.QtCore.QObject, cache: dict, cacheKey: str): ...
    def _BaseEditor__registerHandlers(self, state: bool): ...
    def _BaseEditor__reparentPackages(self, children, droppedItems, childItemIndex, incomingChildCount, parentPackage, parentItem): ...
    def _BaseEditor__restoreExpansionStateFor(self, locationPath, topLevelLocation): ...
    def _BaseEditor__restoreSelectionStateFor(self, locationPath, topLevelLocation): ...
    def _BaseEditor__restoreTopLevelLocations(self, children, currentRootLocation): ...
    def _BaseEditor__rootChildrenChangedCallback(self, locationPath, children): ...
    def _BaseEditor__rootLocationPolicyEvent(self, *args, **kwds): ...
    def _BaseEditor__saveCurrentSelectionAndExpansionState(self, oldRootLocation: str): ...
    def _BaseEditor__selectionChangedHandler(self, syncSelection: bool = ...): ...
    def _BaseEditor__syncSelectionEvent(self, args: list): ...
    def _BaseEditor__syncSelectionValueChanged(self, event): ...
    def _BaseEditor__tabAreaClearWidgets(self): ...
    def _BaseEditor__tabAreaHandleChangesForLocation(self, locationPath: str): ...
    def _BaseEditor__tabAreaHandleChangesForLocationSync(self, locationPath: str): ...
    def _BaseEditor__tabAreaRepaintWithWidgetsForPackage(self, package: PackageSuperToolAPI.Packages.Package): ...
    def _BaseEditor__tabAreaScheduleUpdate(self): ...
    def _BaseEditor__tabAreaSetEditedLocation(self, locationPath: str | None): ...
    def _BaseEditor__tabAreaSetEditedLocationFromSelection(self): ...
    def _BaseEditor__tabAreaSetEditedLocationFromSelectionSync(self): ...
    def _BaseEditor__tabAreaSetEditedLocationSync(self, locationPath: str | None): ...
    def _BaseEditor__tabAreaSetLabelText(self, message: Incomplete | None = ...): ...
    def _BaseEditor__terminalOpCallback(self, portOpClient, op, graphState: NodegraphAPI.GraphState, txn): ...
    def _BaseEditor__thaw(self): ...
    def _BaseEditor__updateColumnItemDelegates(self): ...
    def _BaseEditor__updateCurrentItem(self): ...
    def _BaseEditor__updatePort(self, port: NodegraphAPI.Port): ...
    def _BaseEditor__updateRootLocation(self, currentRoot): ...
    def _BaseEditor__updateSyncSelection(self, syncSelection): ...
    def _BaseEditor__updateTerminalOps(self, graphState: typing.Optional[NodegraphAPI.GraphState] = ..., txn: Incomplete | None = ...): ...
    def _executeCallbackWhenChildrenReady(self, parentLocationPath: str, callback: typing.Callable, errorMessage: Incomplete | None = ..., **kwargs): ...
    def addTab(self, tabName: str) -> PyQt5.QtWidgets.QWidget: ...
    def canSelectionBeExported(self) -> bool: ...
    def getAddPackageMenuActions(self) -> list[tuple[str, str, bool]]: ...
    def getAttribute(self, locationPath: str, attributeName: str) -> PyFnAttribute | None: ...
    def getChildrenUnder(self, parentPath): ...
    def getDefaultAddMenuGroupName(self) -> str: ...
    @classmethod
    def getDefaultSceneGraphViewTerminalOpUpdates(cls, graphState: NodegraphAPI.GraphState): ...
    @classmethod
    def getDefaultSceneGraphViewTerminalOps(cls, graphState: NodegraphAPI.GraphState): ...
    @classmethod
    def getKeyboardShortcuts(cls) -> None: ...
    @classmethod
    def getLayoutOrientation(cls) -> int: ...
    def getMainNode(self) -> BaseNode: ...
    def getMainPanelWidget(self) -> PyQt5.QtWidgets.QWidget: ...
    def getMenuActions(self) -> list[tuple[str, str, bool]]: ...
    def getPackageForPath(self, locationPath: str, includeEditPackages: bool = ..., createDummyOnMissing: bool = ...) -> PackageSuperToolAPI.Packages.Package | None: ...
    def getSceneGraphView(self) -> UI4.Widgets.SceneGraphView: ...
    @classmethod
    def getSceneGraphViewTerminalOpUpdates(cls, graphState: NodegraphAPI.GraphState, rootLocations: tuple[str, ...]) -> list[tuple[str, PyFnAttribute.GroupAttribute, str]]: ...
    @classmethod
    def getSceneGraphViewTerminalOps(cls, graphState: NodegraphAPI.GraphState, rootLocations: tuple[str, ...]) -> list[tuple[str, PyFnAttribute.GroupAttribute] | Tuple[str, PyFnAttribute.GroupAttribute, str]]: ...
    def getSelectedItems(self) -> list[str]: ...
    def getSelectedPackages(self, includeEditPackages: bool = ..., createDummyOnMissing: bool = ...) -> list[tuple]: ...
    @classmethod
    def getSuperToolName(cls) -> str: ...
    @classmethod
    def getTabNames(cls) -> list[str]: ...
    def getTabWidget(self) -> PyQt5.QtWidgets.QTabWidget: ...
    def getTopLevelPackage(self, package: PackageSuperToolAPI.Packages.Package) -> PackageSuperToolAPI.Packages.Package: ...
    def hideEvent(self, event): ...
    def onSelectionChanged(self): ...
    def populateContextMenu(self, menu: PyQt5.QtWidgets.QMenu): ...
    @classmethod
    def registerAddPackageKeyboardShortcut(cls, packageClass: type): ...
    @classmethod
    def registerKeyboardShortcuts(cls): ...
    @classmethod
    def registerPackageKeyboardShortcuts(cls, packageClass: type): ...
    def removeTab(self, tabName: str): ...
    def setColumnToUpdateOnStateChange(self, columnName): ...
    def setupSceneGraphViewColumns(self): ...
    def setupTabWidget(self): ...
    def showEvent(self, event): ...

class GafferThreeInteractionDelegate(UI4.NodeMaster.NodeInteractionDelegateManager.Delegate):
    def addToNodeSpecificShelfEnvironment(self, targetNode, editor, envDict): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.GLDrawingRoutines as GLDrawingRoutines
import QT4Color as QT4Color
import QT4FormWidgets as QT4FormWidgets
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from QT4FormWidgets.ArrayFormWidget import ArrayFormWidget
from QT4FormWidgets.MultiFormWidget import MultiFormWidget
from UI4.FormMaster.Editors.Layers.LayerWithTransform import LayerWithTransform as LayerWithTransform
from UI4.FormMaster.Editors.Layers.PolicyHelpers import GetPolicyState as GetPolicyState, GetPolicyStateColor as GetPolicyStateColor
from UI4.Widgets.MonitorManipulatorButton import MonitorManipulatorButton as MonitorManipulatorButton
from _typeshed import Incomplete
from typing import Set, Tuple

class PointEditorArrayFormWidget(ArrayFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...

class PointEditorMultiFormWidget(MultiFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...

class PointManipulatorLayer(LayerWithTransform, QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, valuePolicy, *args, **kwargs) -> None: ...
    def _PointManipulatorLayer__buildPopupMenu(self): ...
    def _PointManipulatorLayer__valuePolicy_CB(self, arg: Incomplete | None = ...): ...
    def _dothaw(self): ...
    def defaultProcessEvent(self, event): ...
    def drawOutline(self, pick: bool = ...): ...
    def getColor(self): ...
    def getLabel(self): ...
    def getPoint(self): ...
    def getPointStates(self): ...
    def getValuePolicy(self): ...
    def paintGL(self): ...
    def pickOutline(self, x, y): ...
    def processDragHandleEvent(self, event): ...
    def setPoint(self, point, final): ...

class PolicyList(list):
    def _PolicyList__selectPolicies(self, predicate): ...
    def canHaveCurve(self): ...
    def canHaveExpression(self): ...
    def doAutoKey(self): ...
    def doConstant(self): ...
    def doCurve(self): ...
    def doExpression(self): ...
    def doKey(self): ...
    def doShowCurve(self): ...
    def getCurveAutoKey(self): ...
    def getCurveKey(self): ...
    def isCurveEnabled(self): ...
    def isCurveViewed(self): ...
    def isExpressionEnabled(self): ...
    def isLocked(self): ...

def GetPointPolicyChildren(policy): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import UI4 as UI4
import UI4.Tabs
from _typeshed import Incomplete
from typing import Set, Tuple

def GetEnteredGroupNodeNames() -> dict[UI4.Tabs.NodeGraphTab, str]: ...
def RestoreEnteredGroupNodes(enteredGroupNodeNames: dict[UI4.Tabs.NodeGraphTab, str], oldNodeName: Incomplete | None = ..., newNodeName: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import PolicyHelpers as PolicyHelpers
from UI4.FormMaster.Editors.Layers.LayerWithTransform import LayerWithTransform as LayerWithTransform
from UI4.FormMaster.Editors.Layers.PolicyHelpers import GetPolicyState as GetPolicyState, GetPolicyStateColor as GetPolicyStateColor
from typing import Set, Tuple

POLICY_STATE_CURVE_FLOATING: int
POLICY_STATE_CURVE_KEY: int
POLICY_STATE_CURVE_NO_KEY: int
POLICY_STATE_DEFAULT: int
POLICY_STATE_EXPRESSION: int
POLICY_STATE_LOCKED: int
POLICY_STATE_NORMAL: int



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import PyQt5.QtCore
import QT4FormWidgets as QT4FormWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.FormMaster.States as States
import UI4 as UI4
import Utils as Utils
from QT4FormWidgets.GroupFormWidget import GroupFormWidget
from QT4FormWidgets.PopupFormWidget import PopupFormWidget
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class CalculateInOutThread(PyQt5.QtCore.QThread):
    inOutSet: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, nodeName, reportErrors: bool = ...) -> None: ...
    def run(self): ...

class ChannelGroupFormWidget(GroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _ChannelGroupFormWidget__button_clicked_CB(self): ...

class ExrChannelFormWidget(PopupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _ExrChannelFormWidget__updateOptions(self): ...
    def _ExrChannelFormWidget__valueChanged(self, event): ...
    def _freeze(self): ...
    def _thaw(self): ...

class ExrGroupedChannelsFormWidget(PopupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _ExrGroupedChannelsFormWidget__setComponentValue(self, node: NodegraphAPI.Node, channelComponent, componentValue): ...
    def _ExrGroupedChannelsFormWidget__updateOptions(self): ...
    def _ExrGroupedChannelsFormWidget__valueChanged(self, event): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def valueChangedEvent(self, event): ...

class FileInTimingEditorFormWidget(GroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _FileInTimingEditorFormWidget__actionMenu_CB(self, menu): ...
    def _FileInTimingEditorFormWidget__autoCalc_CB(self): ...
    def _FileInTimingEditorFormWidget__fileValueChanged(self): ...
    def _FileInTimingEditorFormWidget__inOutSet(self, nodeName, errorMsg): ...
    def _FileInTimingEditorFormWidget__lockToGlobals_CB(self, *args): ...
    def _FileInTimingEditorFormWidget__paramChange(self, args): ...
    def _FileInTimingEditorFormWidget__setInOutModes(self): ...
    def _FileInTimingEditorFormWidget__setLockFrameRange(self): ...
    def _FileInTimingEditorFormWidget__updateFrameLabel(self, labelWidget, policy, labelText, errorValue, locked): ...
    def _FileInTimingEditorFormWidget__updateInOut(self, interactive: bool = ...): ...
    def _FileInTimingEditorFormWidget__updateInfo(self): ...
    def _FileInTimingEditorFormWidget__valueChanged(self, event): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def addFormWidgetChild(self, child, atIndex: Incomplete | None = ...): ...

class SimpleChannelGroupFormWidget(GroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from ViewerAPI.ImplicitOpsManager import ImplicitOpsManager as ImplicitOpsManager
from ViewerAPI.ManipulatorBridge import ManipulatorBridge as ManipulatorBridge
from typing import Set, Tuple

CameraDirtyBits_AllDirty: int
CameraDirtyBits_Clean: int
CameraDirtyBits_DirtyParams: int
kFnViewerDelegateLookThrough: int
kFnViewerDelegatePrimary: int
kFnViewerDelegateSources: int
kFnViewportCameraTypeOrthographic: int
kFnViewportCameraTypePerspective: int
kFnViewportCameraTypeSpherical: int
kFnViewportCameraTypeUnknown: int
kViewportLayerPluginVersion: int



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import PyQt5.QtCore
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
from UI4.Widgets.PopupButton import PopupButton as PopupButton
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class GraphStateVariableModel(PyQt5.QtCore.QSortFilterProxyModel):
    def filterAcceptsRow(self, source_row, source_parent): ...
    def headerData(self, section, orientation, role): ...

class GraphStateVariablesPopupButton(PopupButton):
    ICON_NAME: ClassVar[str] = ...
    ICON_NAME_ROLLOVER: ClassVar[str] = ...
    PROJECT_SETTINGS_TAB_NAME: ClassVar[str] = ...
    def __init__(self, parent) -> None: ...
    def _GraphStateVariablesPopupButton__aboutToShow(self): ...
    def _GraphStateVariablesPopupButton__buildTreeView(self, title, parent, model, topWidgets: Incomplete | None = ...): ...
    def _GraphStateVariablesPopupButton__isVariableGlobal(self, name, value): ...
    def _GraphStateVariablesPopupButton__jumpToGlobalSettings(self, link): ...
    def _GraphStateVariablesPopupButton__on_filterFieldWidget_filterUpdate(self, filterText, filterType): ...
    def mousePressEvent(self, event): ...
    def mouseReleaseEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import NodegraphAPI.NodeDelegateManager
from typing import Set, Tuple

_ColorLabels: dict
_PastelLabels: dict
_SHOW: str
_SPI: str
rules: list

class NodeColorDelegate(NodegraphAPI.NodeDelegateManager.SuperDelegate):
    def getPreferredNodeColor(self, nodeType, nodeName): ...
    def processNodeCreate(self, node: NodegraphAPI.Node): ...

def _GetColor(flavors): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import PyFnAttribute as FnAttribute
import PyFnGeolibServices as FnGeolibServices
import NodegraphAPI as NodegraphAPI
from Nodes3DAPI.Node3D import Node3D as Node3D
from Nodes3DAPI.TimingUtils import GetModifiedFrameTime as GetModifiedFrameTime, GetTimingParameterHints as GetTimingParameterHints, GetTimingParameterXML as GetTimingParameterXML
from typing import Set, Tuple

_ExtraHints: dict
_Parameter_XML: str

class Alembic_In(Node3D):
    def __init__(self) -> None: ...
    def _getOpChain(self, interface): ...
    def addParameterHints(self, attrName, inputDict): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import ConfigurationAPI_cmodule as Configuration
import GeoAPI as GeoAPI
import KatanaResources as KatanaResources
import Naming as Naming
import PyOpenColorIO as OCIO
import RenderingAPI as RenderingAPI
import Utils as Utils
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class DirectoryInfo:
    def __init__(self, directoryPath, findSequenceFunc: Incomplete | None = ...) -> None: ...
    def _DirectoryInfo__prepareSequences(self): ...
    def getDirectoryMTime(self): ...
    def getFileList(self): ...
    def getNonSequences(self): ...
    def getSequences(self): ...

class FileInfo:
    TYPE_DIRECTORY: ClassVar[int] = ...
    TYPE_FILE: ClassVar[int] = ...
    TYPE_LINK: ClassVar[int] = ...
    TYPE_SEQUENCE: ClassVar[int] = ...
    _DirectoryCache: ClassVar[dict] = ...
    _UIDCache: ClassVar[dict] = ...
    def __init__(self, directoryPath, fileName: Incomplete | None = ..., sequence: Incomplete | None = ...) -> None: ...
    def _FileInfo__stat(self, path): ...
    def ext(self): ...
    def mtime(self): ...
    def mtimeString(self): ...
    def name(self): ...
    def owner(self): ...
    @classmethod
    def readDirectory(cls, path, sequenceListing: bool = ..., findSequenceFunc: Incomplete | None = ...): ...
    def type(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import UI4.Util.IconManager as IconManager
import UI4.Widgets.SceneGraphView.ItemDelegates as ItemDelegates
import NodegraphAPI as NodegraphAPI
import PackageSuperToolAPI.Packages
import PackageSuperToolAPI.Packages as Packages
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SceneGraphView.SceneGraphViewIconManager as SceneGraphViewIconManager
import UI4.Util.ScenegraphIconManager as ScenegraphIconManager
import UI4.Widgets.SceneGraphView
from UI4.Widgets.SceneGraphView.ColumnDataType import RegisterDataType as RegisterDataType
from UI4.Widgets.SceneGraphView.ItemDelegates.NameItemDelegate import NameItemDelegate
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class PackageNameItemDelegate(NameItemDelegate):
    DefaultColumnWidth: ClassVar[int] = ...
    MaximumColumnWidth: ClassVar[None] = ...
    def __init__(self, bridge: UI4.Widgets.SceneGraphView.Bridge, treeWidget: PyQt5.QtWidgets.QTreeWidget, parent: Incomplete | None = ...) -> None: ...
    def _PackageNameItemDelegate__getEditPackageClass(self, locationPath: str) -> type | None: ...
    def _PackageNameItemDelegate__getErrorOrWarning(self, locationPath: str) -> tuple[bool, bool, str, str]: ...
    def _PackageNameItemDelegate__getIcon(self, iconNameOrFilename: str, desiredResolution: int = ...) -> PyQt5.QtGui.QIcon | None: ...
    def _PackageNameItemDelegate__getPackageFromSceneGraphLocation(self, locationPath: str) -> PackageSuperToolAPI.Packages.Package | None: ...
    def _PackageNameItemDelegate__isErrorOrWarning(self, locationPath) -> bool: ...
    def createEditor(self, parent: PyQt5.QtWidgets.QWidget, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex) -> PyQt5.QtWidgets.QWidget | None: ...
    def initStyleOption(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def setModelData(self, editor: PyQt5.QtWidgets.QWidget, model: PyQt5.QtCore.QAbstractItemModel, index: PyQt5.QtCore.QModelIndex): ...
    def setSuperToolName(self, superToolName: str | None): ...
    def toolTipEvent(self, index: PyQt5.QtCore.QModelIndex): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import PyQt5.QtCore
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from typing import ClassVar, Set, Tuple

class ColorProbeBase:
    _ICON_NAME: ClassVar[str] = ...
    _ICON_NAME_HIGHLIGHT: ClassVar[str] = ...
    _ICON_NAME_ON: ClassVar[str] = ...
    _ICON_NAME_ON_HIGHLIGHT: ClassVar[str] = ...
    def __init__(self, defaultBuffer: int = ..., defaultStat: str = ..., autoClose: bool = ...) -> None: ...
    def _ColorProbeBase__monitor_pixelProbeResult_CB(self, eventType, eventID, **kwargs): ...
    def _fillMenu(self, menu): ...
    def _isEnabled(self): ...
    def _probeResult(self, probeInfo): ...
    def getBuffer(self): ...
    def getStatsType(self): ...
    def isOn(self): ...
    def setOn(self, on): ...

class ColorProbeButton(ToolbarButton, ColorProbeBase):
    monitor_pixelProbeResult: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, **kwargs) -> None: ...
    def _ColorProbeButton__aboutToShowControlMenu_CB(self): ...
    def _ColorProbeButton__toggled_CB(self): ...
    def _isEnabled(self): ...
    def _probeResult(self, probeInfo): ...
    def getControlMenu(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import GeoAPI as GeoAPI
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def RegisterToCamera(node: NodegraphAPI.Node, distance, planeType, cameraProducer, time): ...
def RegisterToNamedCamera(node: NodegraphAPI.Node, distance, planeType, scenegraphSourceNode, time, cameraName: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class GammaWidget(PyQt5.QtWidgets.QFrame):
    valueChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...
    def _GammaWidget__gainGroup_slider_CB(self, meta): ...
    def _GammaWidget__gainGroup_text_CB(self, meta): ...
    def _GammaWidget__gammaDownAction_CB(self): ...
    def _GammaWidget__gammaGroup_slider_CB(self, meta): ...
    def _GammaWidget__gammaGroup_text_CB(self, meta): ...
    def _GammaWidget__gammaResetAction_CB(self): ...
    def _GammaWidget__gammaUpAction_CB(self): ...
    def _GammaWidget__idle_CB(self): ...
    def _GammaWidget__layoutMode_CB(self, index): ...
    def _GammaWidget__muteAll_CB(self): ...
    def _GammaWidget__offsetGroup_slider_CB(self, meta): ...
    def _GammaWidget__offsetGroup_text_CB(self, meta): ...
    def _GammaWidget__queueEmitChange(self): ...
    def _GammaWidget__resetAll_CB(self): ...
    def getGammaGainOffset(self): ...
    def getGraphWidget(self): ...
    def recomputeGraphWidget(self, gamma, gain, offset): ...
    def setGain(self, gain, index: Incomplete | None = ...): ...
    def setGamma(self, gamma, index: Incomplete | None = ...): ...
    def setLayoutFull(self): ...
    def setLayoutMini(self): ...
    def setLayoutNormal(self): ...
    def setOffset(self, offset, index: Incomplete | None = ...): ...

class GraphWidget(PyQt5.QtWidgets.QOpenGLWidget):
    def __init__(self, *args) -> None: ...
    def paintGL(self): ...
    def resizeGL(self, width, height): ...
    def setGammaTable(self, rLut, gLut, bLut): ...

class SliderGroup(PyQt5.QtWidgets.QFrame):
    sliderMoved: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    textChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, labelName, meta, sliderFGColor, defaultValue, defaultText, *args) -> None: ...
    def _SliderGroup__lineEdit_CB(self): ...
    def _SliderGroup__muteButton_CB(self): ...
    def _SliderGroup__slider_CB(self, sliderValue): ...
    def decrement(self): ...
    def getText(self): ...
    def getValue(self): ...
    def increment(self): ...
    def isMuted(self): ...
    def reset(self): ...
    def setMuted(self, isMuted): ...
    def setText(self, text): ...
    def setValue(self, signedValue): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnGeolib
import ViewerAPI
from typing import Set, Tuple

class BaseViewerPluginExtension:
    def onApplyTerminalOps(self, txn: PyFnGeolib.GeolibRuntimeTransaction, inputOp: PyFnGeolib.GeolibRuntimeOp | None, viewerDelegate: ViewerAPI.ViewerDelegate) -> PyFnGeolib.GeolibRuntimeOp: ...
    def onDelegateCreated(self, viewerDelegate: ViewerDelegate, pluginName: str): ...
    def onTabCreated(self, tab: BaseViewerTab): ...
    def onViewportCreated(self, viewportWidget: ViewportWidget, pluginName: str, viewportName: str): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
from QT4FormWidgets.FormWidget import FormWidget
from typing import ClassVar, Set, Tuple

class NodeOrParameterDropLabel(PyQt5.QtWidgets.QLabel):
    parameterDropped: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def dragEnterEvent(self, event): ...
    def dropEvent(self, event): ...

class TeleparamWidget(FormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _TeleparamWidget__buildHostedWidget(self): ...
    def _TeleparamWidget__paramDropped(self, path): ...
    def _buildControlWidget(self, hbox): ...
    def _buildTopAreaLayout(self, layout): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def decorateUserParameterFrame(self, parent): ...
    def valueChangedEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyUtilModule.IRFs as IRFs
import NodegraphAPI as NodegraphAPI
import PyXmlIO as PyXmlIO
from PyUtilModule.ProjectSnapshot import ProjectSnapshot as ProjectSnapshot
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class FullProjectSnapshot(MinimalProjectSnapshot):
    def __init__(self, snapshotParameter: Incomplete | None = ...) -> None: ...
    def getNodeGraphXML(self) -> PyXmlIO.Element: ...

class MinimalProjectSnapshot(ProjectSnapshot):
    def __init__(self, snapshotParameter: Incomplete | None = ...) -> None: ...
    def _snapshotGraphStateVariables(self, rootNode: NodegraphAPI.GroupNode): ...
    def _snapshotIRFs(self) -> list[str]: ...
    def getGlobalGraphStateVariables(self): ...
    def getInteractiveRenderFilters(self) -> list[str]: ...

class ProjectSnapshot:
    class Type:
        kFull: ClassVar[int] = ...
        kMinimal: ClassVar[int] = ...
        kOff: ClassVar[int] = ...
        @staticmethod
        def ToString(snapshotType: int) -> str: ...
    def __init__(self) -> None: ...
    def getGlobalGraphStateVariables(self): ...
    def getInteractiveRenderFilters(self) -> list[str]: ...
    def getSnapshotType(self) -> int: ...

def CreateProjectSnapshot(snapshotType: int = ...) -> ProjectSnapshot: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes2DAPI as Nodes2DAPI
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from typing import Set, Tuple

class RenderFocusLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def paintGL(self): ...
    def processEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4GLLayerStack as QT4GLLayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from QT4GLLayerStack.RectangleLayer import RectangleLayer
from UI4.Tabs.Monitor.Layers.ImageLayerBase import ImageLayerBase as ImageLayerBase
from UI4.Util.GLDrawingRoutines import drawEllipse as drawEllipse, drawSmoothArrow as drawSmoothArrow, drawSmoothCross as drawSmoothCross, drawSmoothCrosshairs as drawSmoothCrosshairs, drawSmoothEllipse as drawSmoothEllipse, drawSmoothHandle as drawSmoothHandle, drawSmoothPoly as drawSmoothPoly, drawSmoothText as drawSmoothText
from typing import Set, Tuple

class RectangleSwipeLayer(RectangleLayer, ImageLayerBase):
    def __init__(self, *args, **kwargs) -> None: ...
    def getViewIndexFromWindowPos(self, qpos): ...
    def paintGL(self): ...
    def processEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Widgets.SceneGraphView.Filtering.Criteria
import Utils as Utils
from UI4.Widgets.SceneGraphView.ColumnDataType import ColumnDataType as ColumnDataType
from UI4.Widgets.SceneGraphView.Filtering.Criteria import Criteria as Criteria
from UI4.Widgets.SceneGraphView.Filtering.Evaluator import Evaluator as Evaluator
from typing import ClassVar, Set, Tuple

class CelEvaluator(Evaluator):
    CriteriaList: ClassVar[list] = ...
    def __init__(self) -> None: ...
    def evaluate(self, value): ...
    def getDefaultCriteria(self): ...
    @classmethod
    def getName(cls): ...
    @classmethod
    def registerCriteriaList(cls): ...

class EqualToEvaluator(Evaluator):
    CriteriaList: ClassVar[list] = ...
    def __init__(self) -> None: ...
    def evaluate(self, value): ...
    def getDefaultCriteria(self): ...
    @classmethod
    def getName(cls): ...
    @classmethod
    def registerCriteriaList(cls): ...

class Evaluator:
    def __init__(self) -> None: ...
    def clearCriteria(self): ...
    def evaluate(self, value) -> bool: ...
    def getCriteria(self): ...
    def getDefaultCriteria(self): ...
    @classmethod
    def getName(cls) -> str: ...
    @classmethod
    def registerCriteriaList(cls) -> list[dict]: ...
    def setCriteria(self, name: str, criteria: Criteria[UI4.Widgets.SceneGraphView.Filtering.Criteria.Criteria]): ...

class FuzzyEqualityEvaluator(Evaluator):
    CriteriaList: ClassVar[list] = ...
    def __init__(self) -> None: ...
    def evaluate(self, value): ...
    def getDefaultCriteria(self): ...
    @classmethod
    def getName(cls): ...
    @classmethod
    def registerCriteriaList(cls): ...

class GreaterThanEvaluator(Evaluator):
    CriteriaList: ClassVar[list] = ...
    def __init__(self) -> None: ...
    def evaluate(self, value): ...
    def getDefaultCriteria(self): ...
    @classmethod
    def getName(cls): ...
    @classmethod
    def registerCriteriaList(cls): ...

class LessThanEvaluator(Evaluator):
    CriteriaList: ClassVar[list] = ...
    def __init__(self) -> None: ...
    def evaluate(self, value): ...
    def getDefaultCriteria(self): ...
    @classmethod
    def getName(cls): ...
    @classmethod
    def registerCriteriaList(cls): ...

class RegexEvaluator(Evaluator):
    CriteriaList: ClassVar[list] = ...
    def __init__(self) -> None: ...
    def evaluate(self, value): ...
    def getDefaultCriteria(self): ...
    @classmethod
    def getName(cls): ...
    @classmethod
    def registerCriteriaList(cls): ...
    def setCriteria(self, name, criteria): ...

def GetEvaluatorCriteria(name: str) -> list[dict]: ...
def RegisterEvaluator(name: str, evaluatorClass: Evaluator): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def AddAnamorphScale(scaleAmt): ...
def GetAnamorphScales(): ...
def GetDefaultAnamorphScale(): ...
def ShouldDisplayAnamorphScale(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import UI4.FormMaster.States as States
from QT4FormWidgets.PythonValuePolicy import PythonValuePolicy as PythonValuePolicy
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class PythonValuePolicy(PythonValuePolicy):
    RESERVED_NAMES: ClassVar[set] = ...
    def __init__(self, name: str, policyData: dict, parent: Incomplete | None = ..., childOrderList: Incomplete | None = ..., childHintDict: Incomplete | None = ..., isEnabled: bool = ...) -> None: ...
    def _PythonValuePolicy__addSettings(self, policy: QT4FormWidgets.ValuePolicy.AbstractValuePolicy, result: dict): ...
    def addChildPolicy(self, policy: QT4FormWidgets.PythonValuePolicy): ...
    def getChildByName(self, name: str) -> QT4FormWidgets.PythonValuePolicy | None: ...
    def getSettings(self) -> dict: ...
    def getStateAppearance(self, state: set): ...
    def removeChildPolicy(self, policy: QT4FormWidgets.PythonValuePolicy): ...
    def setEnabled(self, enabled: bool): ...

class _ValuelessPythonPolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, name: str, parent: QT4FormWidgets.PythonValuePolicy | None, isEnabled: bool = ...) -> None: ...
    def getName(self) -> str: ...
    def getType(self) -> str: ...
    def getWidgetHints(self) -> dict: ...
    def isEnabled(self) -> bool: ...
    def setEnabled(self, enabled: bool): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
import UI4.Widgets as Widgets
from UI4.Widgets.BaseNodeGraphLayerStack import BaseNodeGraphLayerStack
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class ErrorMessageWarningLabel(PyQt5.QtWidgets.QFrame):
    def __init__(self, parent, errorText) -> None: ...

class NodegraphWidgetLite(BaseNodeGraphLayerStack):
    _NodegraphWidgetLite__pixmaps: ClassVar[dict] = ...
    nodePortChosen: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    pressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, node: NodegraphAPI.Node, restrictPortType: Incomplete | None = ..., additionalLayers: Incomplete | None = ...) -> None: ...
    def _NodegraphWidgetLite__getMenuPopup(self): ...
    def _NodegraphWidgetLite__nodeLinkClick(self, node: NodegraphAPI.Node, portA, portB, x, y): ...
    def _NodegraphWidgetLite__nodePortClick(self, node: NodegraphAPI.Node, which, x, y): ...
    def _NodegraphWidgetLite__portMenuItemChosen(self, item, meta): ...
    def _NodegraphWidgetLite__showMenuPopup(self, x, y): ...
    def event(self, e): ...
    def fillPortMenu(self, menu, node: NodegraphAPI.Node, isInput, onlyConnectedToNode: Incomplete | None = ...): ...
    def frameAll(self): ...
    def getCurrentNodeView(self): ...
    def getNode(self) -> NodegraphAPI.Node: ...
    def getNodeDisplayName(self, node: NodegraphAPI.Node): ...
    def getWorldBounds(self): ...
    def hideEvent(self, event): ...
    def hitTestForTypeWithOptions(self, p, hitType, *args): ...
    def hitTestPoint(self, p): ...
    def idleUpdate(self): ...
    def removeLayers(self): ...
    def resizeEvent(self, evt): ...

class ShadingNetworkPopupButton(PyQt5.QtWidgets.QPushButton):
    _ShadingNetworkPopupButton__pixmaps: ClassVar[dict] = ...
    nodePortChosen: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    popupClosed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, restrictPortType: Incomplete | None = ..., networkAttrMethod: Incomplete | None = ..., additionalLayers: Incomplete | None = ...) -> None: ...
    def _ShadingNetworkPopupButton__buildPopup(self): ...
    def _ShadingNetworkPopupButton__getNetworkHash(self): ...
    def _ShadingNetworkPopupButton__nodePortChosen(self, nodeName, portType, portName): ...
    def _ShadingNetworkPopupButton__popClicked(self): ...
    def _ShadingNetworkPopupButton__popupClosed(self): ...
    def _ShadingNetworkPopupButton__popupShow(self): ...
    def hidePopup(self): ...

class _HidingVBox(PyQt5.QtWidgets.QFrame):
    closeSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    hideSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    networkHash: ClassVar[None] = ...
    showSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self) -> None: ...
    def closeEvent(self, e): ...
    def hideEvent(self, e): ...
    def showEvent(self, e): ...

class _NodeDrawingLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def paintGL(self): ...

class _PortInteractionLayer(QT4GLLayerStack.LayerStack.Layer):
    nodeLinkClick: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    nodePortClick: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args, **kwargs) -> None: ...
    def _PortInteractionLayer__getNodeAndArrowShapeAt(self, position: None): ...
    def _PortInteractionLayer__processKeyPress(self, event: PyQt5.QtGui.QKeyEvent): ...
    def _PortInteractionLayer__processMouseMove(self, event: PyQt5.QtGui.QMouseEvent) -> bool: ...
    def _PortInteractionLayer__processMousePress(self, event: PyQt5.QtGui.QMouseEvent) -> bool: ...
    def paintGL(self): ...
    def processEvent(self, event: PyQt5.QtGui.QEvent): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import UI4.Util.IconManager as IconManager
import NodegraphAPI as NodegraphAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyFnAttribute
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4Widgets as QT4Widgets
import QT4Widgets.FilterablePopupButton
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import Utils as Utils
import typing
from QT4Widgets.FilterablePopupButton import FilterablePopupButton
from QT4Widgets.SortableTreeWidget import SortableTreeWidget
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from UI4.Util.AttributeHistory import AttributeHistory as AttributeHistory
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class AttributeHistoryPopup(_BasePopup):
    def _startHistoryComputation(self): ...

class AttributeHistoryPopupWidget(_BasePopupWidget):
    def _buildPopupWindow(self): ...

class AttributeHistoryTreeWidget(SortableTreeWidget):
    AttributeValueColumnTitle: ClassVar[str] = ...
    GrayIcon: ClassVar[int] = ...
    GreenIcon: ClassVar[int] = ...
    HistoryEntryColumnTitle: ClassVar[str] = ...
    MaxNumValuesToDisplay: ClassVar[int] = ...
    MaxStringCharsToDisplay: ClassVar[int] = ...
    NothingFoundDummyItemText: ClassVar[str] = ...
    ProcessingDummyItemText: ClassVar[str] = ...
    TimerDelay: ClassVar[int] = ...
    _AttributeHistoryTreeWidget__IconFiles: ClassVar[dict] = ...
    _AttributeHistoryTreeWidget__pixmaps: ClassVar[None] = ...
    released: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    @classmethod
    def GetAttributeDataToDisplay(cls, attribute: PyFnAttribute.DataAttribute) -> str: ...
    @classmethod
    def GetDisplayTextAndIconType(cls, historyEntry: str) -> tuple[str, int]: ...
    @classmethod
    def GetPixmap(cls, iconType: int) -> PyQt5.QtGui.QPixmap: ...
    def _AttributeHistoryTreeWidget__addDummyItem(self, text): ...
    def _AttributeHistoryTreeWidget__doHistoryCalculation(self, historyFunction): ...
    def _AttributeHistoryTreeWidget__historyCompleteCallback(self, historyEntries): ...
    def _AttributeHistoryTreeWidget__historyUpdateCallback(self, historyEntries): ...
    def _AttributeHistoryTreeWidget__on_treeWidget_itemActivated(self, item, index): ...
    def _AttributeHistoryTreeWidget__removeDummyItem(self): ...
    def _AttributeHistoryTreeWidget__setCallbacks(self, completeCallback: typing.Callable, updateCallback: typing.Callable): ...
    def _AttributeHistoryTreeWidget__setNodeEdited(self): ...
    def _AttributeHistoryTreeWidget__setNumberOfItems(self, numberOfItems): ...
    def _AttributeHistoryTreeWidget__updateFromHistory(self, historyEntries): ...
    def _AttributeHistoryTreeWidget__updateItem(self, index, historyEntry, attrValueText, meta, iconType): ...
    def deleteHistory(self): ...
    def getAttributeCreationNode(self, completeCallback: typing.Optional[typing.Callable] = ..., updateCallback: typing.Optional[typing.Callable] = ...): ...
    def getAttributeInheritance(self, completeCallback: typing.Optional[typing.Callable] = ..., updateCallback: typing.Optional[typing.Callable] = ...): ...
    def getAttributeSetNode(self, completeCallback: typing.Optional[typing.Callable] = ..., updateCallback: typing.Optional[typing.Callable] = ...): ...
    def getNodeHistory(self, completeCallback: typing.Optional[typing.Callable] = ..., updateCallback: typing.Optional[typing.Callable] = ...): ...
    def initializeHistory(self, locationPath, attributeName, startNode: Incomplete | None = ..., startOp: Incomplete | None = ..., startPort: Incomplete | None = ..., startGraphState: Incomplete | None = ..., delegateNodes: bool = ...): ...
    def setProcessing(self, isProcessing): ...

class AttributeInheritancePopup(_BasePopup):
    def __init__(self, parent) -> None: ...
    def _startHistoryComputation(self): ...

class AttributeInheritancePopupWidget(_BasePopupWidget):
    def _buildPopupWindow(self): ...

class _BasePopup(QT4Widgets.FilterablePopupButton.FilterablePopup):
    class ElidedLabel(PyQt5.QtWidgets.QLabel):
        def minimumSizeHint(self): ...
        def paintEvent(self, event): ...
    ShowInternalNodesPrefKey: ClassVar[str] = ...
    TimerDelay: ClassVar[int] = ...
    def __init__(self, parent) -> None: ...
    def _BasePopup__on_hide(self): ...
    def _BasePopup__on_itemChosen(self): ...
    def _BasePopup__on_pref_changed(self, args): ...
    def _BasePopup__on_showInternalNodesCheckBox_stateChanged(self, state: PyQt5.QtCore.Qt.CheckState): ...
    def _BasePopup__on_timer_timeout(self): ...
    def _BasePopup__refreshFromPrefs(self): ...
    def _BasePopup__setProcessing(self, isProcessing): ...
    def _BasePopup__startProcessing(self): ...
    def _buildTreeWidget(self): ...
    def _getShowInternalNodesCheckBox(self): ...
    def _historyCompleteCallback(self, nodeHistory): ...
    def _historyUpdateCallback(self, nodeHistory): ...
    def _startHistoryComputation(self): ...
    def computeHistory(self, locationPath, attributeName, startNode: Incomplete | None = ..., startOp: Incomplete | None = ..., startPort: Incomplete | None = ..., startGraphState: Incomplete | None = ...): ...

class _BasePopupWidget(FilterablePopupButton):
    pressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent) -> None: ...
    def popup(self, locationPath, attributeName, startNode: Incomplete | None = ..., startOp: Incomplete | None = ..., startPort: Incomplete | None = ..., startGraphState: Incomplete | None = ..., pos: Incomplete | None = ...): ...

def AddAttributeHistoryActionsToMenu(policy: AbstractValuePolicy, menu: QMenu, includeInheritance: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import Decorators as Decorators, EventModule as EventModule, EventModuleCommon as EventModuleCommon, EventModuleDefault as EventModuleDefault, Exceptions as Exceptions, MimeData as MimeData, OpenGLGPUTiming as OpenGLGPUTiming, OpenGLTraceMarker as OpenGLTraceMarker, Plugins as Plugins, UndoStack as UndoStack, WeakMethod as WeakMethod
from Utils.Exceptions import GetExceptionMessage as GetExceptionMessage
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.PaintingUtils as PaintingUtils
import PyQt5.QtWidgets
import QT4FormWidgets.ValuePolicy
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import Set, Tuple

class StateChangeAction(PyQt5.QtWidgets.QAction):
    def __init__(self, policy: QT4FormWidgets.ValuePolicy.AbstractValuePolicy, state: int, text: str, parent: Incomplete | None = ...) -> None: ...
    def _StateChangeAction__on_triggered(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.PaintingUtils as PaintingUtils
import QT4Widgets as QT4Widgets
import QT4Widgets.FilterablePopupButton
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import ResourceFiles as ResourceFiles
from QT4FormWidgets.BaseValueFormWidget import BaseValueFormWidget as BaseValueFormWidget
from QT4FormWidgets.FormWidget import AlignChildLabelWidths as AlignChildLabelWidths, AlignLeftControlWidths as AlignLeftControlWidths, FormWidget as FormWidget, ScrubbingStates as ScrubbingStates
from QT4Widgets.FilterablePopupButton import FilterablePopupButton
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from _typeshed import Incomplete
from typing import Set, Tuple

class FilterablePopupFormWidget(BaseValueFormWidget):
    class Popup(QT4Widgets.FilterablePopupButton.FilterablePopup):
        def __init__(self, valuePolicy, parent: Incomplete | None = ...) -> None: ...
        def _markDirty(self): ...
        def _refreshContents(self): ...
        def _selectCurrentValue(self): ...
        def getValuePolicy(self): ...
        def refresh(self, force: bool = ...): ...

    class PopupButton(FilterablePopupButton):
        def __init__(self, valuePolicy) -> None: ...
        def _buildPopupWindow(self): ...
        def getValuePolicy(self): ...
    def _buildControlWidget(self, layout): ...
    def _buildLabel(self, labelText, pos: int = ...): ...
    def _buildPopupButton(self): ...
    def _itemChosen(self, text, meta): ...
    def _lockChanged(self, state): ...
    def _updateControlWidget(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnGeolib
import UI4.Widgets.SceneGraphView.SceneGraphLocationTranslation as SceneGraphLocationTranslation
from UI4.Util.ClientManager import ClientManager as ClientManager
from typing import Set, Tuple

class SceneGraphViewClientManager(ClientManager):
    def __init__(self) -> None: ...
    def _SceneGraphViewClientManager__isLocationUnder(self, location: str, otherLocation: str) -> bool: ...
    def _getClientForLocation(self, location: str, topLevelLocation: str | None) -> PyFnGeolib.GeolibRuntime.Client: ...
    def topLevelLocationAdded(self, topLevelLocation: str): ...
    def topLevelLocationRemoved(self, topLevelLocation: str): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import Set, Tuple

class DragSizer(PyQt5.QtWidgets.QFrame):
    def __init__(self, parent, allowHorizontal: bool = ..., allowVertical: bool = ...) -> None: ...
    def _DragSizer__resizeParent(self, width, height): ...
    def mouseMoveEvent(self, event): ...
    def mousePressEvent(self, event): ...
    def mouseReleaseEvent(self, event): ...
    def paintEvent(self, event): ...
    def setMinHeight(self, h): ...
    def setMinWidth(self, w): ...

class StretchBox(PyQt5.QtWidgets.QFrame):
    def __init__(self, parent, cacheSizeHint: Incomplete | None = ..., allowHorizontal: bool = ..., allowVertical: bool = ...) -> None: ...
    def _StretchBox__repositionSizer(self): ...
    def _storeSize(self, height): ...
    def childEvent(self, event): ...
    def resizeEvent(self, event): ...
    def showEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def EditBypassedStateExpression(node: NodegraphAPI.Node, parent: Incomplete | None = ...): ...
def IsBypassedStateAnimated(node: NodegraphAPI.Node) -> bool: ...
def IsBypassedStateControlledByExpression(node: NodegraphAPI.Node) -> bool: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import NodegraphAPI as NodegraphAPI
import PyFCurve as PyFCurve
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
from typing import Set, Tuple

def BakeToCurve(policy): ...
def ExportCurveToFile(policy, defaultOptions): ...
def ImportCurveFromFile(policy, context: str = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from _typeshed import Incomplete
from typing import Set, Tuple

def GetParser(): ...
def ParseAndBuildHintDict(inputString, prefix: str = ..., secondaryPrefix: Incomplete | None = ...): ...



# mypy: disable-error-code="misc, no-redef"
from .QtCore import *
from .QtGui import *
from .QtNetwork import *
from .QtQml import *
from .QtWidgets import *
from .QtXml import *
from .QtOpenGL import *
from .QtPrintSupport import *
from .QtQuick import *
from .QtSql import *
from .QtSvg import *
from .QtTest import *
from .QtQuickWidgets import *

__binding__: str



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI.Constants.ApplyWhenOptions as ApplyWhenOptions
import NodegraphAPI.Constants.ApplyWhereOptions as ApplyWhereOptions
import ConditionalStateGrammar as ConditionalStateGrammar
import NodegraphAPI.Constants.ExecutionModeOptions as ExecutionModeOptions
import PyFnAttribute as FnAttribute
import PyFnGeolibServices as FnGeolibServices
import NodegraphAPI as NodegraphAPI
from ConditionalStateGrammar.Parser import ParseCSG as ParseCSG
from Nodes3DAPI.Node3D import Node3D as Node3D
from typing import Set, Tuple

_ExtraHints: dict
_Parameter_XML: str

class OpScript(Node3D):
    def __init__(self) -> None: ...
    def _getOpChain(self, interface): ...
    def addParameterHints(self, attrName, inputDict): ...

def _DoInputRequests(interface, inputBehavior, inputPorts, graphState: NodegraphAPI.GraphState): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnAttribute
import PyFnGeolib
import RenderingAPI as RenderingAPI
from UI4.Widgets.SceneGraphView.SceneGraphLocationTranslation import GetLocationName as GetLocationName, GetParentPath as GetParentPath
from typing import Set, Tuple

class SceneGraphTree:
    def __init__(self) -> None: ...
    def addOrUpdateSceneGraphLocation(self, locationPath: str, locationData: PyFnGeolib.LocationData) -> TreeItem: ...
    def clear(self): ...
    def deleteSceneGraphLocation(self, locationPath): ...
    def getTreeItem(self, locationPath: str) -> TreeItem: ...
    def hasLocation(self, locationPath: str) -> bool: ...

class SceneGraphTreeException(Exception): ...

class TreeItem:
    def __init__(self, locationPath: str, locationData: PyFnGeolib.LocationData, parentTreeItem: TreeItem | None) -> None: ...
    def _TreeItem__clearLookupMaps(self): ...
    def _TreeItem__populateIndexToNameLookupMap(self): ...
    def _TreeItem__populateNameToIndexLookupMap(self): ...
    def addChild(self, childTreeItem): ...
    def deleteChild(self, childTreeItem): ...
    def getAttributeData(self, attributeName: str, returnResolvedData: bool = ...) -> str | float | int | list | None: ...
    def getAttributes(self) -> PyFnAttribute.Attribute: ...
    def getChildByName(self, locationName: str) -> TreeItem: ...
    def getChildBySceneGraphIndex(self, sceneGraphIndex): ...
    def getChildItems(self) -> list[TreeItem]: ...
    def getChildNames(self) -> list[str]: ...
    def getLocationData(self) -> PyFnGeolib.LocationData: ...
    def getLocationName(self) -> str: ...
    def getLocationPath(self) -> str: ...
    def getLocationType(self) -> str | None: ...
    def getNumberOfChildren(self) -> int: ...
    def getParent(self) -> TreeItem | None: ...
    def getPotentialChildren(self) -> list: ...
    def getSceneGraphIndexInParent(self): ...
    def getSceneGraphIndexOfChildTreeItem(self, childTreeItem): ...
    def getSceneGraphIndexOfLocationName(self, locationName): ...
    def updateLocationData(self, locationData: PyFnGeolib.LocationData): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import Constants as Constants, Exceptions as Exceptions, LookFileUtil as LookFileUtil, OutputFormatAPI as OutputFormatAPI, Utils as Utils
from LookFileBakeAPI.Constants import OutputFormat as OutputFormat
from LookFileBakeAPI.Exceptions import LookFileBakeException as LookFileBakeException
from LookFileBakeAPI.LookFileBaker import BakePrePostHandlerBase as BakePrePostHandlerBase, LookFileBaker as LookFileBaker
from LookFileBakeAPI.LookFileUtil import CreateLookFileDirectory as CreateLookFileDirectory, LocationIntervalEvictor as LocationIntervalEvictor, TraversalObserverBase as TraversalObserverBase
from LookFileBakeAPI.OutputFormatAPI import BaseLookFileBakeOutputFormat as BaseLookFileBakeOutputFormat, GetDefaultOutputFormat as GetDefaultOutputFormat, GetOutputFormatByName as GetOutputFormatByName, GetOutputFormatFileExtensions as GetOutputFormatFileExtensions, GetOutputFormatNames as GetOutputFormatNames, GetOutputFormats as GetOutputFormats, LookFileBakeSettings as LookFileBakeSettings, LookFilePassData as LookFilePassData, RegisterOutputFormat as RegisterOutputFormat, SetDefaultOutputFormat as SetDefaultOutputFormat, UnregisterOutputFormat as UnregisterOutputFormat
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4Color.ColorPolicy as ColorPolicy
import QT4Color.ColorTransforms as ColorTransforms
import QT4Color.DropType as DropType
import QT4Color.Globals as Globals
import QT4Color.Gradient1D as Gradient1D
import PyOpenColorIO as OCIO
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import QT4Color.ScreenScraper as ScreenScraper
from QT4Color.ColorDropWidget import ColorDropWidget as ColorDropWidget
from QT4Color.ColorFormWidget import ColorComponentTabGroup as ColorComponentTabGroup, UpdateThrottler as UpdateThrottler
from QT4Color.ColorTextWidget import ColorTextWidget as ColorTextWidget
from QT4Color.Gradient2D import Gradient2DWidget as Gradient2DWidget
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class ColorPicker(ColorPickerBase):
    def __init__(self, colorObj: Incomplete | None = ...) -> None: ...
    def _cancelClicked(self): ...
    def _okClicked(self): ...
    def closeEvent(self, e): ...

class ColorPickerBase(PyQt5.QtWidgets.QFrame):
    _ColorPickerBase__COLOR_DROP_HEIGHT: ClassVar[int] = ...
    _ColorPickerBase__COLOR_DROP_WIDTH: ClassVar[int] = ...
    accepted: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    colorPicker_setColor: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    rejected: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, colorPolicy: Incomplete | None = ..., parent: Incomplete | None = ..., widgetFactory: Incomplete | None = ...) -> None: ...
    def _ColorPickerBase__addUpdateThrottlerCallbackToChildPolicies(self): ...
    def _ColorPickerBase__applyFilmlookCheckboxCB(self, checkState): ...
    def _ColorPickerBase__buildLayout(self, widgetFactory): ...
    def _ColorPickerBase__clampColor(self, color): ...
    def _ColorPickerBase__colorSampleDropCB(self, dropEvent): ...
    def _ColorPickerBase__colorTextValueChangedCB(self, color): ...
    def _ColorPickerBase__componentGradientValueChangedCB(self, color, final): ...
    def _ColorPickerBase__enableColorClampingCheckboxCB(self, checkState): ...
    def _ColorPickerBase__gradientComponentCapsuleCB(self, newEnabledItems, oldEnabledItems): ...
    def _ColorPickerBase__on_destroyed(self): ...
    def _ColorPickerBase__screenScraperCB(self, scrapedColor, final): ...
    def _ColorPickerBase__stateChangeHandler(self, event): ...
    def _ColorPickerBase__update(self): ...
    def _cancelClicked(self): ...
    def _okClicked(self): ...
    def getColorPolicy(self): ...
    def getPickingColorspace(self): ...
    def resetColor(self): ...
    def setColor(self, color, final: bool = ...): ...
    def setReadOnly(self, value): ...
    def updateColorSampleDragData(self): ...

class ModalColorPicker(MovableDialog):
    modalColorPicker_setColor: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, colorPolicy) -> None: ...
    def _ModalColorPicker__shouldHideWindowFrame(self): ...
    def closeEvent(self, event): ...
    def colorChange(self, color): ...
    def getColor(self): ...

class MovableDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def mouseMoveEvent(self, mouseEvent): ...
    def mousePressEvent(self, mouseEvent): ...
    def mouseReleaseEvent(self, mouseEvent): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from typing import Set, Tuple

class CatalogItemCommentEditor(PyQt5.QtWidgets.QLineEdit):
    def __init__(self, *args) -> None: ...
    def _CatalogItemCommentEditor__catalog_itemDelete_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogItemCommentEditor__catalog_itemUserCommentUpdate_CB(self, eventType, eventID, item): ...
    def _CatalogItemCommentEditor__editingFinished_CB(self): ...
    def setCatalogItem(self, item): ...
    def updateState(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import FarmAPI
import KatanaResources as KatanaResources
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

class FarmPluginManagerException(Exception): ...

class JobRequest:
    def __init__(self, nodeName: str, renderContextName: str, frames: list[int], commands: list[str], environment, tempDir: str) -> None: ...

def CopyRenderFiles(renderFiles: list[str], renderContextName: Incomplete | None = ..., farm: Incomplete | None = ...): ...
def CreateRenderContextName(sequenceID: Incomplete | None = ...) -> str: ...
def CreateTemporaryDirectory(renderContextName: str, farm: Incomplete | None = ...) -> str: ...
def GetDefaultFarm() -> str: ...
def GetFarmPluginNames() -> list[str]: ...
def GetJobState(jobId: str, farm: Incomplete | None = ...) -> str: ...
def GetJobs(filters: Incomplete | None = ..., farm: Incomplete | None = ...) -> list[FarmAPI.Job]: ...
def GetRenderLogFilename(jobId: str, farm: Incomplete | None = ...) -> str | None: ...
def Initialize(): ...
def LoadFarmPlugins(): ...
def PrepareRemoteCommand(localCommandLine: str, renderContextName: str, remoteTempDirectory: str, farm: Incomplete | None = ...) -> str: ...
def SetDefaultFarm(farm: str): ...
def StartJob(jobId: str, farm: Incomplete | None = ...): ...
def StopJob(jobId: str, farm: Incomplete | None = ...): ...
def SubmitJob(nodeName: str, renderContextName: str, remoteTempDir: str, commands: list[str], farm: Incomplete | None = ...) -> str: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
from QT4FormWidgets.FWidget import FWidget
from _typeshed import Incomplete
from typing import Set, Tuple

class FilterablePopupFWidget(FWidget):
    def __init__(self, parent, pixmap: Incomplete | None = ...) -> None: ...
    def _FilterablePopupFWidget__popupHidden(self): ...
    def _FilterablePopupFWidget__popupShow(self): ...
    def getPopup(self): ...
    def mousePressEvent(self, event): ...
    def paint(self, painter, width, height): ...
    def sizeHint(self): ...
    def updateFrame(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyOpenColorIO as OCIO
import PyQt5.QtCore
import QT4Color as QT4Color
import PyQt5.QtCore as QtCore
import UI4 as UI4
from typing import ClassVar, Set, Tuple

class DrawState(PyQt5.QtCore.QObject):
    MATTE_MULT_NONE: ClassVar[int] = ...
    MATTE_MULT_PREMULT: ClassVar[int] = ...
    MATTE_MULT_UNPREMULT: ClassVar[int] = ...
    SWIZZLE_ALPHA: ClassVar[tuple] = ...
    SWIZZLE_BLUE: ClassVar[tuple] = ...
    SWIZZLE_COLOR: ClassVar[tuple] = ...
    SWIZZLE_GREEN: ClassVar[tuple] = ...
    SWIZZLE_LUMA: ClassVar[tuple] = ...
    SWIZZLE_RED: ClassVar[tuple] = ...
    _SWIZZLE_NAMES: ClassVar[dict] = ...
    calculateViewRangeSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    calculateViewRangeZSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    drawStateUpdated: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    kGettersToCompare: ClassVar[list] = ...
    def __init__(self, *args) -> None: ...
    def _DrawState__gamutTimer_CB(self): ...
    def _DrawState__recomputeDisplayCC(self): ...
    def adopt(self, other, emit): ...
    def calculateViewRange(self): ...
    def calculateViewRangeZ(self): ...
    def emitChangeSignal(self): ...
    def getCC(self): ...
    def getCeilCheckValue(self): ...
    def getCurrentGamutCheckColor(self): ...
    def getDefaultInputColorspace(self): ...
    def getDefaultView(self): ...
    def getDisplay(self): ...
    def getDisplayRequest(self): ...
    def getFStopOffset(self): ...
    def getFloorCheckValue(self): ...
    def getInputColorSpaces(self): ...
    def getInputColorspace(self): ...
    def getLayerSelection(self): ...
    def getMatteMult(self): ...
    def getMatteOverlay(self): ...
    def getMatteOverlayColor(self): ...
    def getMatteOverlayInvert(self): ...
    def getSwizzle(self): ...
    def getSwizzleName(self): ...
    def getView(self): ...
    def getViewAdjustmentsMuted(self): ...
    def getViewGamma(self): ...
    def getViewMax(self): ...
    def getViewMin(self): ...
    def getViews(self): ...
    def invertViewRange(self): ...
    def isCeilCheckEnabled(self): ...
    def isFloorCheckEnabled(self): ...
    def isGamutCheckTimerActiveAndUseful(self): ...
    def isInfCheckEnabled(self): ...
    def isNanCheckEnabled(self): ...
    def resetChecks(self): ...
    def resetLayerSelection(self): ...
    def resetViewRange(self): ...
    def setCC(self, cc): ...
    def setCeilCheckEnabled(self, doCheck): ...
    def setCeilCheckValue(self, value): ...
    def setDisplay(self, display): ...
    def setFStopOffset(self, fstop): ...
    def setFloorCheckEnabled(self, doCheck): ...
    def setFloorCheckValue(self, value): ...
    def setInfCheckEnabled(self, doCheck): ...
    def setInputColorspace(self, csname): ...
    def setLayerSelection(self, layerSelection): ...
    def setMatteMult(self, state): ...
    def setMatteOverlay(self, state): ...
    def setMatteOverlayColor(self, state): ...
    def setMatteOverlayInvert(self, state): ...
    def setNanCheckEnabled(self, doCheck): ...
    def setSwizzle(self, mode): ...
    def setView(self, name): ...
    def setViewAdjustmentsMuted(self, val): ...
    def setViewGamma(self, val): ...
    def setViewMax(self, val): ...
    def setViewMin(self, val): ...
    def setViewToNormals(self): ...
    def startGamutCheckTimer(self, interval, colors): ...
    def stopGamutCheckTimer(self): ...
    def __eq__(self, other) -> bool: ...
    def __lt__(self, other) -> bool: ...

def GetDefaultOverlayColor(): ...
def GetDefaultOverlayColorPolicy(): ...
